# AUTO-GENERATED FILE -- DO NOT EDIT


AFMT_A_LAW = 2
AFMT_MU_LAW = 1
AFMT_S16_BE = 32
AFMT_S16_LE = 16
AFMT_S16_NE = 16
AFMT_S8 = 64
AFMT_U16_BE = 256
AFMT_U16_LE = 128
AFMT_U8 = 8
__package__ = None

class error(Exception):

  pass

def open():
  pass




# AUTO-GENERATED FILE -- DO NOT EDIT

""" Conversion between binary data and ASCII """

class Error(Exception):

  pass

class Incomplete(Exception):

  pass

__package__ = None

def a2b_base64(ascii):
  """ (ascii) -> bin. Decode a line of base64 data """
  return None

def a2b_hex(hexstr):
  """ a2b_hex(hexstr) -> s; Binary data of hexadecimal representation.
  
  hexstr must contain an even number of hex digits (upper or lower case).
  This function is also available as "unhexlify()" """
  return None

def a2b_hqx(ascii):
  """ ascii -> bin, done. Decode .hqx coding """
  return None

def a2b_qp():
  """ Decode a string of qp-encoded data """
  pass

def a2b_uu(ascii):
  """ (ascii) -> bin. Decode a line of uuencoded data """
  return None

def b2a_base64(bin):
  """ (bin) -> ascii. Base64-code line of data """
  return None

def b2a_hex(data):
  """ b2a_hex(data) -> s; Hexadecimal representation of binary data.
  
  This function is also available as "hexlify()". """
  return None

def b2a_hqx():
  """ Encode .hqx data """
  pass

def b2a_qp(data, quotetabs=0, istext=1, header=0):
  """ b2a_qp(data, quotetabs=0, istext=1, header=0) -> s; 
   Encode a string using quoted-printable encoding. 
  
  On encoding, when istext is set, newlines are not encoded, and white 
  space at end of lines is.  When istext is not set, \\r and \\n (CR/LF) are 
  both encoded.  When quotetabs is set, space and tabs are encoded. """
  return None

def b2a_uu(bin):
  """ (bin) -> ascii. Uuencode line of data """
  return None

def crc32(data, arg0=None):
  """ (data, oldcrc = 0) -> newcrc. Compute CRC-32 incrementally """
  return None

def crc_hqx(data, oldcrc):
  """ (data, oldcrc) -> newcrc. Compute hqx CRC incrementally """
  return None

def hexlify(data):
  """ b2a_hex(data) -> s; Hexadecimal representation of binary data.
  
  This function is also available as "hexlify()". """
  return None

def rlecode_hqx():
  """ Binhex RLE-code binary data """
  pass

def rledecode_hqx():
  """ Decode hexbin RLE-coded string """
  pass

def unhexlify(hexstr):
  """ a2b_hex(hexstr) -> s; Binary data of hexadecimal representation.
  
  hexstr must contain an even number of hex digits (upper or lower case).
  This function is also available as "unhexlify()" """
  return None




# AUTO-GENERATED FILE -- DO NOT EDIT


__package__ = None

class error(Exception):

  pass

library = 'GNU gdbm'

def open(path, flag=None, mode=None):
  """ open(path[, flag[, mode]]) -> mapping
  Return a database object. """
  return None




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QHelpContentItem():
    """"""
    def childPosition(self, child):
        '''int QHelpContentItem.childPosition(QHelpContentItem child)'''
        return int()
    def parent(self):
        '''QHelpContentItem QHelpContentItem.parent()'''
        return QHelpContentItem()
    def row(self):
        '''int QHelpContentItem.row()'''
        return int()
    def url(self):
        '''QUrl QHelpContentItem.url()'''
        return QUrl()
    def title(self):
        '''str QHelpContentItem.title()'''
        return str()
    def childCount(self):
        '''int QHelpContentItem.childCount()'''
        return int()
    def child(self, row):
        '''QHelpContentItem QHelpContentItem.child(int row)'''
        return QHelpContentItem()


class QHelpContentModel(QAbstractItemModel):
    """"""
    contentsCreated = pyqtSignal() # void contentsCreated() - signal
    contentsCreationStarted = pyqtSignal() # void contentsCreationStarted() - signal
    def isCreatingContents(self):
        '''bool QHelpContentModel.isCreatingContents()'''
        return bool()
    def columnCount(self, parent = QModelIndex()):
        '''int QHelpContentModel.columnCount(QModelIndex parent = QModelIndex())'''
        return int()
    def rowCount(self, parent = QModelIndex()):
        '''int QHelpContentModel.rowCount(QModelIndex parent = QModelIndex())'''
        return int()
    def parent(self, index):
        '''QModelIndex QHelpContentModel.parent(QModelIndex index)'''
        return QModelIndex()
    def index(self, row, column, parent = QModelIndex()):
        '''QModelIndex QHelpContentModel.index(int row, int column, QModelIndex parent = QModelIndex())'''
        return QModelIndex()
    def data(self, index, role):
        '''QVariant QHelpContentModel.data(QModelIndex index, int role)'''
        return QVariant()
    def contentItemAt(self, index):
        '''QHelpContentItem QHelpContentModel.contentItemAt(QModelIndex index)'''
        return QHelpContentItem()
    def createContents(self, customFilterName):
        '''void QHelpContentModel.createContents(str customFilterName)'''


class QHelpContentWidget(QTreeView):
    """"""
    linkActivated = pyqtSignal() # void linkActivated(const QUrlamp;) - signal
    def indexOf(self, link):
        '''QModelIndex QHelpContentWidget.indexOf(QUrl link)'''
        return QModelIndex()


class QHelpEngineCore(QObject):
    """"""
    def __init__(self, collectionFile, parent = None):
        '''void QHelpEngineCore.__init__(str collectionFile, QObject parent = None)'''
    readersAboutToBeInvalidated = pyqtSignal() # void readersAboutToBeInvalidated() - signal
    warning = pyqtSignal() # void warning(const QStringamp;) - signal
    currentFilterChanged = pyqtSignal() # void currentFilterChanged(const QStringamp;) - signal
    setupFinished = pyqtSignal() # void setupFinished() - signal
    setupStarted = pyqtSignal() # void setupStarted() - signal
    def setAutoSaveFilter(self, save):
        '''void QHelpEngineCore.setAutoSaveFilter(bool save)'''
    def autoSaveFilter(self):
        '''bool QHelpEngineCore.autoSaveFilter()'''
        return bool()
    def error(self):
        '''str QHelpEngineCore.error()'''
        return str()
    def metaData(self, documentationFileName, name):
        '''static QVariant QHelpEngineCore.metaData(str documentationFileName, str name)'''
        return QVariant()
    def setCustomValue(self, key, value):
        '''bool QHelpEngineCore.setCustomValue(str key, QVariant value)'''
        return bool()
    def customValue(self, key, defaultValue = None):
        '''QVariant QHelpEngineCore.customValue(str key, QVariant defaultValue = None)'''
        return QVariant()
    def removeCustomValue(self, key):
        '''bool QHelpEngineCore.removeCustomValue(str key)'''
        return bool()
    def linksForIdentifier(self, id):
        '''dict-of-QString-QUrl QHelpEngineCore.linksForIdentifier(str id)'''
        return {str():QUrl()}
    def fileData(self, url):
        '''QByteArray QHelpEngineCore.fileData(QUrl url)'''
        return QByteArray()
    def findFile(self, url):
        '''QUrl QHelpEngineCore.findFile(QUrl url)'''
        return QUrl()
    def files(self, namespaceName, filterAttributes, extensionFilter = None):
        '''list-of-QUrl QHelpEngineCore.files(str namespaceName, list-of-str filterAttributes, str extensionFilter = '')'''
        return [QUrl()]
    def filterAttributeSets(self, namespaceName):
        '''list-of-QStringList QHelpEngineCore.filterAttributeSets(str namespaceName)'''
        return [strList()]
    def registeredDocumentations(self):
        '''list-of-str QHelpEngineCore.registeredDocumentations()'''
        return [str()]
    def setCurrentFilter(self, filterName):
        '''void QHelpEngineCore.setCurrentFilter(str filterName)'''
    def currentFilter(self):
        '''str QHelpEngineCore.currentFilter()'''
        return str()
    def filterAttributes(self):
        '''list-of-str QHelpEngineCore.filterAttributes()'''
        return [str()]
    def filterAttributes(self, filterName):
        '''list-of-str QHelpEngineCore.filterAttributes(str filterName)'''
        return [str()]
    def addCustomFilter(self, filterName, attributes):
        '''bool QHelpEngineCore.addCustomFilter(str filterName, list-of-str attributes)'''
        return bool()
    def removeCustomFilter(self, filterName):
        '''bool QHelpEngineCore.removeCustomFilter(str filterName)'''
        return bool()
    def customFilters(self):
        '''list-of-str QHelpEngineCore.customFilters()'''
        return [str()]
    def documentationFileName(self, namespaceName):
        '''str QHelpEngineCore.documentationFileName(str namespaceName)'''
        return str()
    def unregisterDocumentation(self, namespaceName):
        '''bool QHelpEngineCore.unregisterDocumentation(str namespaceName)'''
        return bool()
    def registerDocumentation(self, documentationFileName):
        '''bool QHelpEngineCore.registerDocumentation(str documentationFileName)'''
        return bool()
    def namespaceName(self, documentationFileName):
        '''static str QHelpEngineCore.namespaceName(str documentationFileName)'''
        return str()
    def copyCollectionFile(self, fileName):
        '''bool QHelpEngineCore.copyCollectionFile(str fileName)'''
        return bool()
    def setCollectionFile(self, fileName):
        '''void QHelpEngineCore.setCollectionFile(str fileName)'''
    def collectionFile(self):
        '''str QHelpEngineCore.collectionFile()'''
        return str()
    def setupData(self):
        '''bool QHelpEngineCore.setupData()'''
        return bool()


class QHelpEngine(QHelpEngineCore):
    """"""
    def __init__(self, collectionFile, parent = None):
        '''void QHelpEngine.__init__(str collectionFile, QObject parent = None)'''
    def searchEngine(self):
        '''QHelpSearchEngine QHelpEngine.searchEngine()'''
        return QHelpSearchEngine()
    def indexWidget(self):
        '''QHelpIndexWidget QHelpEngine.indexWidget()'''
        return QHelpIndexWidget()
    def contentWidget(self):
        '''QHelpContentWidget QHelpEngine.contentWidget()'''
        return QHelpContentWidget()
    def indexModel(self):
        '''QHelpIndexModel QHelpEngine.indexModel()'''
        return QHelpIndexModel()
    def contentModel(self):
        '''QHelpContentModel QHelpEngine.contentModel()'''
        return QHelpContentModel()


class QHelpIndexModel(QStringListModel):
    """"""
    indexCreated = pyqtSignal() # void indexCreated() - signal
    indexCreationStarted = pyqtSignal() # void indexCreationStarted() - signal
    def isCreatingIndex(self):
        '''bool QHelpIndexModel.isCreatingIndex()'''
        return bool()
    def linksForKeyword(self, keyword):
        '''dict-of-QString-QUrl QHelpIndexModel.linksForKeyword(str keyword)'''
        return {str():QUrl()}
    def filter(self, filter, wildcard = None):
        '''QModelIndex QHelpIndexModel.filter(str filter, str wildcard = '')'''
        return QModelIndex()
    def createIndex(self, customFilterName):
        '''void QHelpIndexModel.createIndex(str customFilterName)'''


class QHelpIndexWidget(QListView):
    """"""
    def activateCurrentItem(self):
        '''void QHelpIndexWidget.activateCurrentItem()'''
    def filterIndices(self, filter, wildcard = None):
        '''void QHelpIndexWidget.filterIndices(str filter, str wildcard = '')'''
    linksActivated = pyqtSignal() # void linksActivated(const QMaplt;QString,QUrlgt;amp;,const QStringamp;) - signal
    linkActivated = pyqtSignal() # void linkActivated(const QUrlamp;,const QStringamp;) - signal


class QHelpSearchQuery():
    """"""
    # Enum QHelpSearchQuery.FieldName
    DEFAULT = 0
    FUZZY = 0
    WITHOUT = 0
    PHRASE = 0
    ALL = 0
    ATLEAST = 0

    def __init__(self):
        '''void QHelpSearchQuery.__init__()'''
    def __init__(self, field, wordList):
        '''void QHelpSearchQuery.__init__(QHelpSearchQuery.FieldName field, list-of-str wordList)'''
    def __init__(self):
        '''QHelpSearchQuery QHelpSearchQuery.__init__()'''
        return QHelpSearchQuery()


class QHelpSearchEngine(QObject):
    """"""
    def __init__(self, helpEngine, parent = None):
        '''void QHelpSearchEngine.__init__(QHelpEngineCore helpEngine, QObject parent = None)'''
    searchingFinished = pyqtSignal() # void searchingFinished(int) - signal
    searchingStarted = pyqtSignal() # void searchingStarted() - signal
    indexingFinished = pyqtSignal() # void indexingFinished() - signal
    indexingStarted = pyqtSignal() # void indexingStarted() - signal
    def cancelSearching(self):
        '''void QHelpSearchEngine.cancelSearching()'''
    def search(self, queryList):
        '''void QHelpSearchEngine.search(list-of-QHelpSearchQuery queryList)'''
    def cancelIndexing(self):
        '''void QHelpSearchEngine.cancelIndexing()'''
    def reindexDocumentation(self):
        '''void QHelpSearchEngine.reindexDocumentation()'''
    def hits(self, start, end):
        '''list-of-tuple-of-QString-QString QHelpSearchEngine.hits(int start, int end)'''
        return [tuple-of-str-str()]
    def hitCount(self):
        '''int QHelpSearchEngine.hitCount()'''
        return int()
    def resultWidget(self):
        '''QHelpSearchResultWidget QHelpSearchEngine.resultWidget()'''
        return QHelpSearchResultWidget()
    def queryWidget(self):
        '''QHelpSearchQueryWidget QHelpSearchEngine.queryWidget()'''
        return QHelpSearchQueryWidget()
    def query(self):
        '''list-of-QHelpSearchQuery QHelpSearchEngine.query()'''
        return [QHelpSearchQuery()]


class QHelpSearchQueryWidget(QWidget):
    """"""
    def __init__(self, parent = None):
        '''void QHelpSearchQueryWidget.__init__(QWidget parent = None)'''
    def setCompactMode(self, on):
        '''void QHelpSearchQueryWidget.setCompactMode(bool on)'''
    def isCompactMode(self):
        '''bool QHelpSearchQueryWidget.isCompactMode()'''
        return bool()
    search = pyqtSignal() # void search() - signal
    def collapseExtendedSearch(self):
        '''void QHelpSearchQueryWidget.collapseExtendedSearch()'''
    def expandExtendedSearch(self):
        '''void QHelpSearchQueryWidget.expandExtendedSearch()'''
    def setQuery(self, queryList):
        '''void QHelpSearchQueryWidget.setQuery(list-of-QHelpSearchQuery queryList)'''
    def query(self):
        '''list-of-QHelpSearchQuery QHelpSearchQueryWidget.query()'''
        return [QHelpSearchQuery()]


class QHelpSearchResultWidget(QWidget):
    """"""
    requestShowLink = pyqtSignal() # void requestShowLink(const QUrlamp;) - signal
    def linkAt(self, point):
        '''QUrl QHelpSearchResultWidget.linkAt(QPoint point)'''
        return QUrl()





# SPDX-FileCopyrightText: 2025 Jarmo Tiitto <jarmo.tiitto@gmail.com>
# SPDX-License-Identifier: GPL-2.0-or-later
"""Accurate skipping past and out of conditional code blocks."""
import dis
from collections import namedtuple

# pylint disable=R1710, R0915

_asmskip_opcode_cache = {}

def disassemble(f_code):
    '''Disassemble a code object, with jump info.
       * Instruction columns are resolved to a minimum column of the originating source line.
         'RESUME' instruction is ignored for the code object's minimum column.
       * Any instructions part of an source line that does a jump are marked as "jumping".
       * Returns a AsmInstr list and the code object's minimum column.
    '''
    # A simple associative cache.
    entry = _asmskip_opcode_cache.get(f_code, None)
    if entry:
        return entry
    # Later ins part of a lineno can change already appended AsmInstr(s):
    # A proxy list objects are used to allow updating the past AsmInstr(s).
    AsmInstr = namedtuple(
        'AsmInstr', [
            'opcode',
            'opname',
            'oparg',
            'lineno',
            'offset',
            'jump_target',
            'column',
            'jumping'
        ])
    asm_list = []
    lineno_info = {}
    min_column = -1
    for ins in dis.get_instructions(f_code):
        lineno = -1 if ins.line_number is None else ins.line_number
        column = -1 if ins.positions.col_offset is None else ins.positions.col_offset
        if ins.opcode != dis.opmap['RESUME']:
            if min_column == -1:
                min_column = column
            min_column = min(min_column, column)
        if lineno not in lineno_info:
            lineno_info[lineno] = [[column], [False]]
        if lineno_info[lineno][0][0] > column:
            lineno_info[lineno][0][0] = column
        if ins.jump_target is not None:
            lineno_info[lineno][1][0] = True
        asm_list.append(AsmInstr(
            ins.opcode,
            ins.opname,
            ins.argrepr,
            lineno,
            ins.offset,
            ins.jump_target,
            lineno_info[lineno][0],
            lineno_info[lineno][1]))
    asm_list = [AsmInstr(x[0], x[1], x[2], x[3], x[4], x[5], x[6][0], x[7][0]) for x in asm_list]
    _asmskip_opcode_cache[f_code] = (asm_list, min_column)
    return asm_list, min_column


_asmskip_stepout_cache = {}

def stepout_lineno(f_code, curr_lineno):
    '''Look ahead in the code object and find a source line past curr_line such that:
       1. Skip past a single block if it starts at the curr_lineno source line.
       2. Step out from "for", "while" and "if" blocks:
          Blocks contained in the curr_lineno source line's block and after it line are skipped.
       3. Else, return -1.
    '''
    jump_targets = {} # set of the forward jump instr offsets
    forend_lineno = -1
    ins = None # current AsmInstr (updated in the for-loop)
    # The code is arranged into inner functions.
    process_goal = None
    def past_endfor():
        if forend_lineno < ins.lineno:
            return ins.lineno
        return None

    def maybe_reached_jump_target():
        if ins.opcode != dis.opmap['END_FOR']:
            return ins.lineno
        # Find next ins with greater than ins.lineno:
        nonlocal forend_lineno
        forend_lineno = ins.lineno
        nonlocal process_goal
        process_goal = past_endfor
        return None

    # Jump target updating.
    jump_filter = None

    def want_all_jumps():
        if ins.jump_target is not None and ins.jump_target > ins.offset:
            nonlocal jump_targets
            jump_targets[ins.jump_target] = False

    def want_no_jumps():
        return

    def want_next_jump():
        if ins.jump_target is not None and ins.jump_target > ins.offset:
            nonlocal jump_targets
            # discard all earlier jump targets, only ins.jump_target is wanted.
            jump_targets.clear()
            jump_targets[ins.jump_target] = False
            nonlocal jump_filter
            jump_filter = want_no_jumps

    def past_single_jump():
        nonlocal process_goal
        nonlocal jump_targets
        nonlocal jump_filter
        if jump_targets.pop(ins.offset, False):
            jump_filter = want_no_jumps
            ret = maybe_reached_jump_target()
            if ret is not None:
                return ret
        return None

    # seek_to_curr_lineno() requires min_column
    asm_list, min_column = disassemble(f_code)

    def seek_to_curr_lineno():
        '''find first ins of curr_lineno source line.'''
        nonlocal jump_targets
        if ins.lineno < curr_lineno:
            # Discard reached jump targets while seeking to first ins of curr_lineno.
            jump_targets.pop(ins.offset, None)
            return None
        # Reached first ins of curr_lineno.
        # ins can be a target of earlier jump. We want to go past it, so discard it.
        jump_targets.pop(ins.offset, None)
        nonlocal process_goal
        nonlocal jump_filter
        if ins.jumping:
            # Find a target past of this starting single block.
            process_goal = past_single_jump
            # Accept the soon following jump target.
            jump_filter = want_next_jump
            return None
        if ins.column <= min_column or not jump_targets:
            # No pending jump targets exist, or the starting ins.column is <= min_column.
            return -1
        # Find a target past of the current block.
        # New jump targets are ignored.
        process_goal = past_single_jump
        jump_filter = want_no_jumps
        return None

    # get cached starting index.
    cache = _asmskip_stepout_cache.setdefault(id(f_code), {})
    if curr_lineno in cache:
        index = cache[curr_lineno]
    else:
        # (binary search would be nice, except asm_list is not sorted by lineno.)
        index = 0
        for index, ins in enumerate(asm_list):
            if ins.lineno >= curr_lineno:
                break
        until_index = index
        while index > 0:
            if asm_list[index].column <= min_column:
                break
            index -= 1
        for i in range(index, until_index):
            cache[asm_list[i].lineno] = index

    # Process loop.
    process_goal = seek_to_curr_lineno
    jump_filter = want_all_jumps
    for ins in asm_list[index:]:
        # track forward jump targets.
        jump_filter()
        if ins.offset in jump_targets:
            jump_targets[ins.offset] = True
        ret = process_goal()
        if ret is not None:
            return ret
    return -1



#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Core tools for working with streams.
"""
"""
An int containing the default buffer size used by the module's buffered I/O
classes.  :func:`.open` uses the file's blksize (as obtained by
:func:`os.stat`) if possible.

"""
DEFAULT_BUFFER_SIZE = None
def open(file,mode='r',buffering=_1,encoding=None,errors=None,newline=None,closefd=True):
	"""
	Open *file* and return a corresponding stream.  If the file cannot be opened,
	an :exc:`IOError` is raised.
	
	*file* is either a string giving the pathname (absolute or
	relative to the current working directory) of the file to be opened or
	an integer file descriptor of the file to be wrapped.  (If a file descriptor
	is given, it is closed when the returned I/O object is closed, unless
	*closefd* is set to ``False``.)
	
	*mode* is an optional string that specifies the mode in which the file is
	opened.  It defaults to ``'r'`` which means open for reading in text mode.
	Other common values are ``'w'`` for writing (truncating the file if it
	already exists), and ``'a'`` for appending (which on *some* Unix systems,
	means that *all* writes append to the end of the file regardless of the
	current seek position).  In text mode, if *encoding* is not specified the
	encoding used is platform dependent. (For reading and writing raw bytes use
	binary mode and leave *encoding* unspecified.)  The available modes are:
	
	========= ===============================================================
	Character Meaning
	--------- ---------------------------------------------------------------
	``'r'``   open for reading (default)
	``'w'``   open for writing, truncating the file first
	``'a'``   open for writing, appending to the end of the file if it exists
	``'b'``   binary mode
	``'t'``   text mode (default)
	``'+'``   open a disk file for updating (reading and writing)
	``'U'``   universal newline mode (for backwards compatibility; should
	not be used in new code)
	========= ===============================================================
	
	The default mode is ``'rt'`` (open for reading text).  For binary random
	access, the mode ``'w+b'`` opens and truncates the file to 0 bytes, while
	``'r+b'`` opens the file without truncation.
	
	Python distinguishes between files opened in binary and text modes, even when
	the underlying operating system doesn't.  Files opened in binary mode
	(including ``'b'`` in the *mode* argument) return contents as :class:`bytes`
	objects without any decoding.  In text mode (the default, or when ``'t'`` is
	included in the *mode* argument), the contents of the file are returned as
	:class:`unicode` strings, the bytes having been first decoded using a
	platform-dependent encoding or using the specified *encoding* if given.
	
	*buffering* is an optional integer used to set the buffering policy.
	Pass 0 to switch buffering off (only allowed in binary mode), 1 to select
	line buffering (only usable in text mode), and an integer > 1 to indicate
	the size of a fixed-size chunk buffer.  When no *buffering* argument is
	given, the default buffering policy works as follows:
	
	* Binary files are buffered in fixed-size chunks; the size of the buffer
	is chosen using a heuristic trying to determine the underlying device's
	"block size" and falling back on :attr:`DEFAULT_BUFFER_SIZE`.
	On many systems, the buffer will typically be 4096 or 8192 bytes long.
	
	* "Interactive" text files (files for which :meth:`isatty` returns True)
	use line buffering.  Other text files use the policy described above
	for binary files.
	
	*encoding* is the name of the encoding used to decode or encode the file.
	This should only be used in text mode.  The default encoding is platform
	dependent (whatever :func:`locale.getpreferredencoding` returns), but any
	encoding supported by Python can be used.  See the :mod:`codecs` module for
	the list of supported encodings.
	
	*errors* is an optional string that specifies how encoding and decoding
	errors are to be handled--this cannot be used in binary mode.  Pass
	``'strict'`` to raise a :exc:`ValueError` exception if there is an encoding
	error (the default of ``None`` has the same effect), or pass ``'ignore'`` to
	ignore errors.  (Note that ignoring encoding errors can lead to data loss.)
	``'replace'`` causes a replacement marker (such as ``'?'``) to be inserted
	where there is malformed data.  When writing, ``'xmlcharrefreplace'``
	(replace with the appropriate XML character reference) or
	``'backslashreplace'`` (replace with backslashed escape sequences) can be
	used.  Any other error handling name that has been registered with
	:func:`codecs.register_error` is also valid.
	
	*newline* controls how universal newlines works (it only applies to text
	mode).  It can be ``None``, ``''``, ``'\n'``, ``'\r'``, and ``'\r\n'``.  It
	works as follows:
	
	* On input, if *newline* is ``None``, universal newlines mode is enabled.
	Lines in the input can end in ``'\n'``, ``'\r'``, or ``'\r\n'``, and these
	are translated into ``'\n'`` before being returned to the caller.  If it is
	``''``, universal newline mode is enabled, but line endings are returned to
	the caller untranslated.  If it has any of the other legal values, input
	lines are only terminated by the given string, and the line ending is
	returned to the caller untranslated.
	
	* On output, if *newline* is ``None``, any ``'\n'`` characters written are
	translated to the system default line separator, :data:`os.linesep`.  If
	*newline* is ``''``, no translation takes place.  If *newline* is any of
	the other legal values, any ``'\n'`` characters written are translated to
	the given string.
	
	If *closefd* is ``False`` and a file descriptor rather than a filename was
	given, the underlying file descriptor will be kept open when the file is
	closed.  If a filename is given *closefd* has no effect and must be ``True``
	(the default).
	
	The type of file object returned by the :func:`.open` function depends on the
	mode.  When :func:`.open` is used to open a file in a text mode (``'w'``,
	``'r'``, ``'wt'``, ``'rt'``, etc.), it returns a subclass of
	:class:`TextIOBase` (specifically :class:`TextIOWrapper`).  When used to open
	a file in a binary mode with buffering, the returned class is a subclass of
	:class:`BufferedIOBase`.  The exact class varies: in read binary mode, it
	returns a :class:`BufferedReader`; in write binary and append binary modes,
	it returns a :class:`BufferedWriter`, and in read/write mode, it returns a
	:class:`BufferedRandom`.  When buffering is disabled, the raw stream, a
	subclass of :class:`RawIOBase`, :class:`FileIO`, is returned.
	
	It is also possible to use an :class:`unicode` or :class:`bytes` string
	as a file for both reading and writing.  For :class:`unicode` strings
	:class:`StringIO` can be used like a file opened in text mode,
	and for :class:`bytes` a :class:`BytesIO` can be used like a
	file opened in a binary mode.
	
	
	"""
	pass
	
class IOBase:


	"""
	The abstract base class for all I/O classes, acting on streams of bytes.
	There is no public constructor.
	
	This class provides empty abstract implementations for many methods
	that derived classes can override selectively; the default
	implementations represent a file that cannot be read, written or
	seeked.
	
	Even though :class:`IOBase` does not declare :meth:`read`, :meth:`readinto`,
	or :meth:`write` because their signatures will vary, implementations and
	clients should consider those methods part of the interface.  Also,
	implementations may raise a :exc:`IOError` when operations they do not
	support are called.
	
	The basic type used for binary data read from or written to a file is
	:class:`bytes` (also known as :class:`str`).  :class:`bytearray`\s are
	accepted too, and in some cases (such as :class:`readinto`) required.
	Text I/O classes work with :class:`unicode` data.
	
	Note that calling any method (even inquiries) on a closed stream is
	undefined.  Implementations may raise :exc:`IOError` in this case.
	
	IOBase (and its subclasses) support the iterator protocol, meaning that an
	:class:`IOBase` object can be iterated over yielding the lines in a stream.
	Lines are defined slightly differently depending on whether the stream is
	a binary stream (yielding :class:`bytes`), or a text stream (yielding
	:class:`unicode` strings).  See :meth:`readline` below.
	
	IOBase is also a context manager and therefore supports the
	:keyword:`with` statement.  In this example, *file* is closed after the
	:keyword:`with` statement's suite is finished---even if an exception occurs::
	
	with io.open('spam.txt', 'w') as file:
	file.write(u'Spam and eggs!')
	
	:class:`IOBase` provides these data attributes and methods:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def close(self, ):
		"""
		Flush and close this stream. This method has no effect if the file is
		already closed. Once the file is closed, any operation on the file
		(e.g. reading or writing) will raise a :exc:`ValueError`.
		
		As a convenience, it is allowed to call this method more than once;
		only the first call, however, will have an effect.
		
		"""
		pass
		
	def fileno(self, ):
		"""
		Return the underlying file descriptor (an integer) of the stream if it
		exists.  An :exc:`IOError` is raised if the IO object does not use a file
		descriptor.
		
		"""
		pass
		
	def flush(self, ):
		"""
		Flush the write buffers of the stream if applicable.  This does nothing
		for read-only and non-blocking streams.
		
		"""
		pass
		
	def isatty(self, ):
		"""
		Return ``True`` if the stream is interactive (i.e., connected to
		a terminal/tty device).
		
		"""
		pass
		
	def readable(self, ):
		"""
		Return ``True`` if the stream can be read from.  If False, :meth:`read`
		will raise :exc:`IOError`.
		
		"""
		pass
		
	def readline(self, limit=_1):
		"""
		Read and return one line from the stream.  If *limit* is specified, at
		most *limit* bytes will be read.
		
		The line terminator is always ``b'\n'`` for binary files; for text files,
		the *newlines* argument to :func:`.open` can be used to select the line
		terminator(s) recognized.
		
		"""
		pass
		
	def readlines(self, hint=_1):
		"""
		Read and return a list of lines from the stream.  *hint* can be specified
		to control the number of lines read: no more lines will be read if the
		total size (in bytes/characters) of all lines so far exceeds *hint*.
		
		"""
		pass
		
	def seek(self, offset,whence=SEEK_SET):
		"""
		Change the stream position to the given byte *offset*.  *offset* is
		interpreted relative to the position indicated by *whence*.  Values for
		*whence* are:
		
		* :data:`SEEK_SET` or ``0`` -- start of the stream (the default);
		*offset* should be zero or positive
		* :data:`SEEK_CUR` or ``1`` -- current stream position; *offset* may
		be negative
		* :data:`SEEK_END` or ``2`` -- end of the stream; *offset* is usually
		negative
		
		Return the new absolute position.
		
		"""
		pass
		
	def seekable(self, ):
		"""
		Return ``True`` if the stream supports random access.  If ``False``,
		:meth:`seek`, :meth:`tell` and :meth:`truncate` will raise :exc:`IOError`.
		
		"""
		pass
		
	def tell(self, ):
		"""
		Return the current stream position.
		
		"""
		pass
		
	def truncate(self, size=None):
		"""
		Resize the stream to the given *size* in bytes (or the current position
		if *size* is not specified).  The current stream position isn't changed.
		This resizing can extend or reduce the current file size.  In case of
		extension, the contents of the new file area depend on the platform
		(on most systems, additional bytes are zero-filled, on Windows they're
		undetermined).  The new file size is returned.
		
		"""
		pass
		
	def writable(self, ):
		"""
		Return ``True`` if the stream supports writing.  If ``False``,
		:meth:`write` and :meth:`truncate` will raise :exc:`IOError`.
		
		"""
		pass
		
	def writelines(self, lines):
		"""
		Write a list of lines to the stream.  Line separators are not added, so it
		is usual for each of the lines provided to have a line separator at the
		end.
		
		
		"""
		pass
		
	


class RawIOBase:


	"""
	Base class for raw binary I/O.  It inherits :class:`IOBase`.  There is no
	public constructor.
	
	Raw binary I/O typically provides low-level access to an underlying OS
	device or API, and does not try to encapsulate it in high-level primitives
	(this is left to Buffered I/O and Text I/O, described later in this page).
	
	In addition to the attributes and methods from :class:`IOBase`,
	RawIOBase provides the following methods:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def read(self, n=_1):
		"""
		Read up to *n* bytes from the object and return them.  As a convenience,
		if *n* is unspecified or -1, :meth:`readall` is called.  Otherwise,
		only one system call is ever made.  Fewer than *n* bytes may be
		returned if the operating system call returns fewer than *n* bytes.
		
		If 0 bytes are returned, and *n* was not 0, this indicates end of file.
		If the object is in non-blocking mode and no bytes are available,
		``None`` is returned.
		
		"""
		pass
		
	def readall(self, ):
		"""
		Read and return all the bytes from the stream until EOF, using multiple
		calls to the stream if necessary.
		
		"""
		pass
		
	def readinto(self, b):
		"""
		Read up to len(b) bytes into bytearray *b* and return the number
		of bytes read.  If the object is in non-blocking mode and no
		bytes are available, ``None`` is returned.
		
		"""
		pass
		
	def write(self, b):
		"""
		Write the given bytes or bytearray object, *b*, to the underlying raw
		stream and return the number of bytes written.  This can be less than
		``len(b)``, depending on specifics of the underlying raw stream, and
		especially if it is in non-blocking mode.  ``None`` is returned if the
		raw stream is set not to block and no single byte could be readily
		written to it.
		
		
		"""
		pass
		
	


class BufferedIOBase:


	"""
	Base class for binary streams that support some kind of buffering.
	It inherits :class:`IOBase`. There is no public constructor.
	
	The main difference with :class:`RawIOBase` is that methods :meth:`read`,
	:meth:`readinto` and :meth:`write` will try (respectively) to read as much
	input as requested or to consume all given output, at the expense of
	making perhaps more than one system call.
	
	In addition, those methods can raise :exc:`BlockingIOError` if the
	underlying raw stream is in non-blocking mode and cannot take or give
	enough data; unlike their :class:`RawIOBase` counterparts, they will
	never return ``None``.
	
	Besides, the :meth:`read` method does not have a default
	implementation that defers to :meth:`readinto`.
	
	A typical :class:`BufferedIOBase` implementation should not inherit from a
	:class:`RawIOBase` implementation, but wrap one, like
	:class:`BufferedWriter` and :class:`BufferedReader` do.
	
	:class:`BufferedIOBase` provides or overrides these members in addition to
	those from :class:`IOBase`:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def detach(self, ):
		"""
		Separate the underlying raw stream from the buffer and return it.
		
		After the raw stream has been detached, the buffer is in an unusable
		state.
		
		Some buffers, like :class:`BytesIO`, do not have the concept of a single
		raw stream to return from this method.  They raise
		:exc:`UnsupportedOperation`.
		
		"""
		pass
		
	def read(self, n=_1):
		"""
		Read and return up to *n* bytes.  If the argument is omitted, ``None``, or
		negative, data is read and returned until EOF is reached.  An empty bytes
		object is returned if the stream is already at EOF.
		
		If the argument is positive, and the underlying raw stream is not
		interactive, multiple raw reads may be issued to satisfy the byte count
		(unless EOF is reached first).  But for interactive raw streams, at most
		one raw read will be issued, and a short result does not imply that EOF is
		imminent.
		
		A :exc:`BlockingIOError` is raised if the underlying raw stream is in
		non blocking-mode, and has no data available at the moment.
		
		"""
		pass
		
	def read1(self, n=_1):
		"""
		Read and return up to *n* bytes, with at most one call to the underlying
		raw stream's :meth:`~RawIOBase.read` method.  This can be useful if you
		are implementing your own buffering on top of a :class:`BufferedIOBase`
		object.
		
		"""
		pass
		
	def readinto(self, b):
		"""
		Read up to len(b) bytes into bytearray *b* and return the number of bytes
		read.
		
		Like :meth:`read`, multiple reads may be issued to the underlying raw
		stream, unless the latter is 'interactive'.
		
		A :exc:`BlockingIOError` is raised if the underlying raw stream is in
		non blocking-mode, and has no data available at the moment.
		
		"""
		pass
		
	def write(self, b):
		"""
		Write the given bytes or bytearray object, *b* and return the number
		of bytes written (never less than ``len(b)``, since if the write fails
		an :exc:`IOError` will be raised).  Depending on the actual
		implementation, these bytes may be readily written to the underlying
		stream, or held in a buffer for performance and latency reasons.
		
		When in non-blocking mode, a :exc:`BlockingIOError` is raised if the
		data needed to be written to the raw stream but it couldn't accept
		all the data without blocking.
		
		
		Raw File I/O
		"""
		pass
		
	


class FileIO:


	"""
	:class:`FileIO` represents an OS-level file containing bytes data.
	It implements the :class:`RawIOBase` interface (and therefore the
	:class:`IOBase` interface, too).
	
	The *name* can be one of two things:
	
	* a string representing the path to the file which will be opened;
	* an integer representing the number of an existing OS-level file descriptor
	to which the resulting :class:`FileIO` object will give access.
	
	The *mode* can be ``'r'``, ``'w'`` or ``'a'`` for reading (default), writing,
	or appending.  The file will be created if it doesn't exist when opened for
	writing or appending; it will be truncated when opened for writing.  Add a
	``'+'`` to the mode to allow simultaneous reading and writing.
	
	The :meth:`read` (when called with a positive argument), :meth:`readinto`
	and :meth:`write` methods on this class will only make one system call.
	
	In addition to the attributes and methods from :class:`IOBase` and
	:class:`RawIOBase`, :class:`FileIO` provides the following data
	attributes and methods:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	


class BytesIO:


	"""
	A stream implementation using an in-memory bytes buffer.  It inherits
	:class:`BufferedIOBase`.
	
	The argument *initial_bytes* is an optional initial :class:`bytes`.
	
	:class:`BytesIO` provides or overrides these methods in addition to those
	from :class:`BufferedIOBase` and :class:`IOBase`:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def getvalue(self, ):
		"""
		Return ``bytes`` containing the entire contents of the buffer.
		
		"""
		pass
		
	def read1(self, ):
		"""
		In :class:`BytesIO`, this is the same as :meth:`read`.
		
		
		"""
		pass
		
	


class BufferedReader:


	"""
	A buffer providing higher-level access to a readable, sequential
	:class:`RawIOBase` object.  It inherits :class:`BufferedIOBase`.
	When reading data from this object, a larger amount of data may be
	requested from the underlying raw stream, and kept in an internal buffer.
	The buffered data can then be returned directly on subsequent reads.
	
	The constructor creates a :class:`BufferedReader` for the given readable
	*raw* stream and *buffer_size*.  If *buffer_size* is omitted,
	:data:`DEFAULT_BUFFER_SIZE` is used.
	
	:class:`BufferedReader` provides or overrides these methods in addition to
	those from :class:`BufferedIOBase` and :class:`IOBase`:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def peek(self, n):
		"""
		Return bytes from the stream without advancing the position.  At most one
		single read on the raw stream is done to satisfy the call. The number of
		bytes returned may be less or more than requested.
		
		"""
		pass
		
	def read(self, n):
		"""
		Read and return *n* bytes, or if *n* is not given or negative, until EOF
		or if the read call would block in non-blocking mode.
		
		"""
		pass
		
	def read1(self, n):
		"""
		Read and return up to *n* bytes with only one call on the raw stream.  If
		at least one byte is buffered, only buffered bytes are returned.
		Otherwise, one raw stream read call is made.
		
		
		"""
		pass
		
	


class BufferedWriter:


	"""
	A buffer providing higher-level access to a writeable, sequential
	:class:`RawIOBase` object.  It inherits :class:`BufferedIOBase`.
	When writing to this object, data is normally held into an internal
	buffer.  The buffer will be written out to the underlying :class:`RawIOBase`
	object under various conditions, including:
	
	* when the buffer gets too small for all pending data;
	* when :meth:`flush()` is called;
	* when a :meth:`seek()` is requested (for :class:`BufferedRandom` objects);
	* when the :class:`BufferedWriter` object is closed or destroyed.
	
	The constructor creates a :class:`BufferedWriter` for the given writeable
	*raw* stream.  If the *buffer_size* is not given, it defaults to
	:data:`DEFAULT_BUFFER_SIZE`.
	
	A third argument, *max_buffer_size*, is supported, but unused and deprecated.
	
	:class:`BufferedWriter` provides or overrides these methods in addition to
	those from :class:`BufferedIOBase` and :class:`IOBase`:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def flush(self, ):
		"""
		Force bytes held in the buffer into the raw stream.  A
		:exc:`BlockingIOError` should be raised if the raw stream blocks.
		
		"""
		pass
		
	def write(self, b):
		"""
		Write the bytes or bytearray object, *b* and return the number of bytes
		written.  When in non-blocking mode, a :exc:`BlockingIOError` is raised
		if the buffer needs to be written out but the raw stream blocks.
		
		
		"""
		pass
		
	


class BufferedRWPair:


	"""
	A buffered I/O object giving a combined, higher-level access to two
	sequential :class:`RawIOBase` objects: one readable, the other writeable.
	It is useful for pairs of unidirectional communication channels
	(pipes, for instance).  It inherits :class:`BufferedIOBase`.
	
	*reader* and *writer* are :class:`RawIOBase` objects that are readable and
	writeable respectively.  If the *buffer_size* is omitted it defaults to
	:data:`DEFAULT_BUFFER_SIZE`.
	
	A fourth argument, *max_buffer_size*, is supported, but unused and
	deprecated.
	
	:class:`BufferedRWPair` implements all of :class:`BufferedIOBase`\'s methods
	except for :meth:`~BufferedIOBase.detach`, which raises
	:exc:`UnsupportedOperation`.
	
	
	"""
	
	
	def __init__(self, ):
		pass
	
	


class BufferedRandom:


	"""
	A buffered interface to random access streams.  It inherits
	:class:`BufferedReader` and :class:`BufferedWriter`, and further supports
	:meth:`seek` and :meth:`tell` functionality.
	
	The constructor creates a reader and writer for a seekable raw stream, given
	in the first argument.  If the *buffer_size* is omitted it defaults to
	:data:`DEFAULT_BUFFER_SIZE`.
	
	A third argument, *max_buffer_size*, is supported, but unused and deprecated.
	
	:class:`BufferedRandom` is capable of anything :class:`BufferedReader` or
	:class:`BufferedWriter` can do.
	
	
	Text I/O
	--------
	
	"""
	
	
	def __init__(self, ):
		pass
	
	


class TextIOBase:


	"""
	Base class for text streams.  This class provides an unicode character
	and line based interface to stream I/O.  There is no :meth:`readinto`
	method because Python's :class:`unicode` strings are immutable.
	It inherits :class:`IOBase`.  There is no public constructor.
	
	:class:`TextIOBase` provides or overrides these data attributes and
	methods in addition to those from :class:`IOBase`:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def detach(self, ):
		"""
		Separate the underlying binary buffer from the :class:`TextIOBase` and
		return it.
		
		After the underlying buffer has been detached, the :class:`TextIOBase` is
		in an unusable state.
		
		Some :class:`TextIOBase` implementations, like :class:`StringIO`, may not
		have the concept of an underlying buffer and calling this method will
		raise :exc:`UnsupportedOperation`.
		
		"""
		pass
		
	def read(self, n):
		"""
		Read and return at most *n* characters from the stream as a single
		:class:`unicode`.  If *n* is negative or ``None``, reads until EOF.
		
		"""
		pass
		
	def readline(self, ):
		"""
		Read until newline or EOF and return a single ``unicode``.  If the
		stream is already at EOF, an empty string is returned.
		
		"""
		pass
		
	def write(self, s):
		"""
		Write the :class:`unicode` string *s* to the stream and return the
		number of characters written.
		
		
		"""
		pass
		
	


class TextIOWrapper:


	"""
	A buffered text stream over a :class:`BufferedIOBase` binary stream.
	It inherits :class:`TextIOBase`.
	
	*encoding* gives the name of the encoding that the stream will be decoded or
	encoded with.  It defaults to :func:`locale.getpreferredencoding`.
	
	*errors* is an optional string that specifies how encoding and decoding
	errors are to be handled.  Pass ``'strict'`` to raise a :exc:`ValueError`
	exception if there is an encoding error (the default of ``None`` has the same
	effect), or pass ``'ignore'`` to ignore errors.  (Note that ignoring encoding
	errors can lead to data loss.)  ``'replace'`` causes a replacement marker
	(such as ``'?'``) to be inserted where there is malformed data.  When
	writing, ``'xmlcharrefreplace'`` (replace with the appropriate XML character
	reference) or ``'backslashreplace'`` (replace with backslashed escape
	sequences) can be used.  Any other error handling name that has been
	registered with :func:`codecs.register_error` is also valid.
	
	*newline* can be ``None``, ``''``, ``'\n'``, ``'\r'``, or ``'\r\n'``.  It
	controls the handling of line endings.  If it is ``None``, universal newlines
	is enabled.  With this enabled, on input, the lines endings ``'\n'``,
	``'\r'``, or ``'\r\n'`` are translated to ``'\n'`` before being returned to
	the caller.  Conversely, on output, ``'\n'`` is translated to the system
	default line separator, :data:`os.linesep`.  If *newline* is any other of its
	legal values, that newline becomes the newline when the file is read and it
	is returned untranslated.  On output, ``'\n'`` is converted to the *newline*.
	
	If *line_buffering* is ``True``, :meth:`flush` is implied when a call to
	write contains a newline character.
	
	:class:`TextIOWrapper` provides one attribute in addition to those of
	:class:`TextIOBase` and its parents:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	


class StringIO:


	"""
	An in-memory stream for unicode text.  It inherits :class:`TextIOWrapper`.
	
	The initial value of the buffer (an empty unicode string by default) can
	be set by providing *initial_value*.  The *newline* argument works like
	that of :class:`TextIOWrapper`.  The default is to do no newline
	translation.
	
	:class:`StringIO` provides this method in addition to those from
	:class:`TextIOWrapper` and its parents:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def getvalue(self, ):
		"""
		Return a ``unicode`` containing the entire contents of the buffer at any
		time before the :class:`StringIO` object's :meth:`close` method is
		called.
		
		Example usage::
		
		import io
		
		output = io.StringIO()
		output.write(u'First line.\n')
		output.write(u'Second line.\n')
		
		# Retrieve file contents -- this will be
		# u'First line.\nSecond line.\n'
		contents = output.getvalue()
		
		# Close object and discard memory buffer --
		# .getvalue() will now raise an exception.
		output.close()
		
		
		"""
		pass
		
	





# AUTO-GENERATED FILE -- DO NOT EDIT

""" Functional tools for creating and using iterators.

Infinite iterators:
count([n]) --> n, n+1, n+2, ...
cycle(p) --> p0, p1, ... plast, p0, p1, ...
repeat(elem [,n]) --> elem, elem, elem, ... endlessly or up to n times

Iterators terminating on the shortest input sequence:
chain(p, q, ...) --> p0, p1, ... plast, q0, q1, ... 
compress(data, selectors) --> (d[0] if s[0]), (d[1] if s[1]), ...
dropwhile(pred, seq) --> seq[n], seq[n+1], starting when pred fails
groupby(iterable[, keyfunc]) --> sub-iterators grouped by value of keyfunc(v)
ifilter(pred, seq) --> elements of seq where pred(elem) is True
ifilterfalse(pred, seq) --> elements of seq where pred(elem) is False
islice(seq, [start,] stop [, step]) --> elements from
       seq[start:stop:step]
imap(fun, p, q, ...) --> fun(p0, q0), fun(p1, q1), ...
starmap(fun, seq) --> fun(*seq[0]), fun(*seq[1]), ...
tee(it, n=2) --> (it1, it2 , ... itn) splits one iterator into n
takewhile(pred, seq) --> seq[0], seq[1], until pred fails
izip(p, q, ...) --> (p[0], q[0]), (p[1], q[1]), ... 
izip_longest(p, q, ...) --> (p[0], q[0]), (p[1], q[1]), ... 

Combinatoric generators:
product(p, q, ... [repeat=1]) --> cartesian product
permutations(p[, r])
combinations(p, r)
combinations_with_replacement(p, r)
 """

__package__ = None

class chain(object):
  """ chain(*iterables) --> chain object
  
  Return a chain object whose .next() method returns elements from the
  first iterable until it is exhausted, then elements from the next
  iterable, until all of the iterables are exhausted. """

  def from_iterable(self, iterable):
    """ chain.from_iterable(iterable) --> chain object
    
    Alternate chain() contructor taking a single iterable argument
    that evaluates lazily. """
    return None

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class combinations(object):
  """ combinations(iterable, r) --> combinations object
  
  Return successive r-length combinations of elements in the iterable.
  
  combinations(range(4), 3) --> (0,1,2), (0,1,3), (0,2,3), (1,2,3) """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class combinations_with_replacement(object):
  """ combinations_with_replacement(iterable, r) --> combinations_with_replacement object
  
  Return successive r-length combinations of elements in the iterable
  allowing individual elements to have successive repeats.
  combinations_with_replacement('ABC', 2) --> AA AB AC BB BC CC """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class compress(object):
  """ compress(data, selectors) --> iterator over selected data
  
  Return data elements corresponding to true selector elements.
  Forms a shorter iterator from selected data elements using the
  selectors to choose the data elements. """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class count(object):
  """ count(start=0, step=1) --> count object
  
  Return a count object whose .next() method returns consecutive values.
  Equivalent to:
  
      def count(firstval=0, step=1):
      x = firstval
      while 1:
          yield x
          x += step
   """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class cycle(object):
  """ cycle(iterable) --> cycle object
  
  Return elements from the iterable until it is exhausted.
  Then repeat the sequence indefinitely. """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class dropwhile(object):
  """ dropwhile(predicate, iterable) --> dropwhile object
  
  Drop items from the iterable while predicate(item) is true.
  Afterwards, return every element until the iterable is exhausted. """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class groupby(object):
  """ groupby(iterable[, keyfunc]) -> create an iterator which returns
  (key, sub-iterator) grouped by each value of key(value).
   """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class filterfalse(object):
  """ filterfalse(function or None, sequence) --> ifilterfalse object
  
  Return those items of sequence for which function(item) is false.
  If function is None, return the items that are false. """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class slice(object):
  """ slice(iterable, [start,] stop [, step]) --> islice object
  
  Return an iterator whose next() method returns selected values from an
  iterable.  If start is specified, will skip all preceding elements;
  otherwise, start defaults to zero.  Step defaults to one.  If
  specified as another value, step determines how many values are 
  skipped between successive calls.  Works like a slice() on a list
  but returns an iterator. """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class zip_longest(object):
  """ zip_longest(iter1 [,iter2 [...]], [fillvalue=None]) --> izip_longest object
  
  Return a zip_longest object whose .next() method returns a tuple where
  the i-th element comes from the i-th iterable argument.  The .next()
  method continues until the longest iterable in the argument sequence
  is exhausted and then it raises StopIteration.  When the shorter iterables
  are exhausted, the fillvalue is substituted in their place.  The fillvalue
  defaults to None or can be specified by a keyword argument.
   """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class permutations(object):
  """ permutations(iterable[, r]) --> permutations object
  
  Return successive r-length permutations of elements in the iterable.
  
  permutations(range(3), 2) --> (0,1), (0,2), (1,0), (1,2), (2,0), (2,1) """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class product(object):
  """ product(*iterables) --> product object
  
  Cartesian product of input iterables.  Equivalent to nested for-loops.
  
  For example, product(A, B) returns the same as:  ((x,y) for x in A for y in B).
  The leftmost iterators are in the outermost for-loop, so the output tuples
  cycle in a manner similar to an odometer (with the rightmost element changing
  on every iteration).
  
  To compute the product of an iterable with itself, specify the number
  of repetitions with the optional repeat keyword argument. For example,
  product(A, repeat=4) means the same as product(A, A, A, A).
  
  product('ab', range(3)) --> ('a',0) ('a',1) ('a',2) ('b',0) ('b',1) ('b',2)
  product((0,1), (0,1), (0,1)) --> (0,0,0) (0,0,1) (0,1,0) (0,1,1) (1,0,0) ... """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class repeat(object):
  """ repeat(object [,times]) -> create an iterator which returns the object
  for the specified number of times.  If not specified, returns the object
  endlessly. """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class starmap(object):
  """ starmap(function, sequence) --> starmap object
  
  Return an iterator whose values are returned from the function evaluated
  with a argument tuple taken from the given sequence. """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

class takewhile(object):
  """ takewhile(predicate, iterable) --> takewhile object
  
  Return successive entries from an iterable as long as the 
  predicate evaluates to true for each entry. """

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

def tee(iterable, n=2):
  """ tee(iterable, n=2) --> tuple of n independent iterators. """
  return ()




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QSensorReading(QObject):
    """"""
    def value(self, index):
        '''QVariant QSensorReading.value(int index)'''
        return QVariant()
    def valueCount(self):
        '''int QSensorReading.valueCount()'''
        return int()
    def setTimestamp(self, timestamp):
        '''void QSensorReading.setTimestamp(int timestamp)'''
    def timestamp(self):
        '''int QSensorReading.timestamp()'''
        return int()


class QAccelerometerReading(QSensorReading):
    """"""
    def setZ(self, z):
        '''void QAccelerometerReading.setZ(float z)'''
    def z(self):
        '''float QAccelerometerReading.z()'''
        return float()
    def setY(self, y):
        '''void QAccelerometerReading.setY(float y)'''
    def y(self):
        '''float QAccelerometerReading.y()'''
        return float()
    def setX(self, x):
        '''void QAccelerometerReading.setX(float x)'''
    def x(self):
        '''float QAccelerometerReading.x()'''
        return float()


class QSensorFilter():
    """"""
    def __init__(self):
        '''void QSensorFilter.__init__()'''
    def __init__(self):
        '''QSensorFilter QSensorFilter.__init__()'''
        return QSensorFilter()
    def filter(self, reading):
        '''abstract bool QSensorFilter.filter(QSensorReading reading)'''
        return bool()


class QAccelerometerFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QAccelerometerFilter.__init__()'''
    def __init__(self):
        '''QAccelerometerFilter QAccelerometerFilter.__init__()'''
        return QAccelerometerFilter()
    def filter(self, reading):
        '''abstract bool QAccelerometerFilter.filter(QAccelerometerReading reading)'''
        return bool()


class QSensor(QObject):
    """"""
    # Enum QSensor.AxesOrientationMode
    FixedOrientation = 0
    AutomaticOrientation = 0
    UserOrientation = 0

    # Enum QSensor.Feature
    Buffering = 0
    AlwaysOn = 0
    GeoValues = 0
    FieldOfView = 0
    AccelerationMode = 0
    SkipDuplicates = 0
    AxesOrientation = 0
    PressureSensorTemperature = 0

    def __init__(self, type, parent = None):
        '''void QSensor.__init__(QByteArray type, QObject parent = None)'''
    bufferSizeChanged = pyqtSignal() # void bufferSizeChanged(int) - signal
    efficientBufferSizeChanged = pyqtSignal() # void efficientBufferSizeChanged(int) - signal
    maxBufferSizeChanged = pyqtSignal() # void maxBufferSizeChanged(int) - signal
    userOrientationChanged = pyqtSignal() # void userOrientationChanged(int) - signal
    currentOrientationChanged = pyqtSignal() # void currentOrientationChanged(int) - signal
    axesOrientationModeChanged = pyqtSignal() # void axesOrientationModeChanged(QSensor::AxesOrientationMode) - signal
    skipDuplicatesChanged = pyqtSignal() # void skipDuplicatesChanged(bool) - signal
    dataRateChanged = pyqtSignal() # void dataRateChanged() - signal
    alwaysOnChanged = pyqtSignal() # void alwaysOnChanged() - signal
    availableSensorsChanged = pyqtSignal() # void availableSensorsChanged() - signal
    sensorError = pyqtSignal() # void sensorError(int) - signal
    readingChanged = pyqtSignal() # void readingChanged() - signal
    activeChanged = pyqtSignal() # void activeChanged() - signal
    busyChanged = pyqtSignal() # void busyChanged() - signal
    def stop(self):
        '''void QSensor.stop()'''
    def start(self):
        '''bool QSensor.start()'''
        return bool()
    def setBufferSize(self, bufferSize):
        '''void QSensor.setBufferSize(int bufferSize)'''
    def bufferSize(self):
        '''int QSensor.bufferSize()'''
        return int()
    def setEfficientBufferSize(self, efficientBufferSize):
        '''void QSensor.setEfficientBufferSize(int efficientBufferSize)'''
    def efficientBufferSize(self):
        '''int QSensor.efficientBufferSize()'''
        return int()
    def setMaxBufferSize(self, maxBufferSize):
        '''void QSensor.setMaxBufferSize(int maxBufferSize)'''
    def maxBufferSize(self):
        '''int QSensor.maxBufferSize()'''
        return int()
    def setUserOrientation(self, userOrientation):
        '''void QSensor.setUserOrientation(int userOrientation)'''
    def userOrientation(self):
        '''int QSensor.userOrientation()'''
        return int()
    def setCurrentOrientation(self, currentOrientation):
        '''void QSensor.setCurrentOrientation(int currentOrientation)'''
    def currentOrientation(self):
        '''int QSensor.currentOrientation()'''
        return int()
    def setAxesOrientationMode(self, axesOrientationMode):
        '''void QSensor.setAxesOrientationMode(QSensor.AxesOrientationMode axesOrientationMode)'''
    def axesOrientationMode(self):
        '''QSensor.AxesOrientationMode QSensor.axesOrientationMode()'''
        return QSensor.AxesOrientationMode()
    def isFeatureSupported(self, feature):
        '''bool QSensor.isFeatureSupported(QSensor.Feature feature)'''
        return bool()
    def defaultSensorForType(self, type):
        '''static QByteArray QSensor.defaultSensorForType(QByteArray type)'''
        return QByteArray()
    def sensorsForType(self, type):
        '''static list-of-QByteArray QSensor.sensorsForType(QByteArray type)'''
        return [QByteArray()]
    def sensorTypes(self):
        '''static list-of-QByteArray QSensor.sensorTypes()'''
        return [QByteArray()]
    def reading(self):
        '''QSensorReading QSensor.reading()'''
        return QSensorReading()
    def filters(self):
        '''list-of-QSensorFilter QSensor.filters()'''
        return [QSensorFilter()]
    def removeFilter(self, filter):
        '''void QSensor.removeFilter(QSensorFilter filter)'''
    def addFilter(self, filter):
        '''void QSensor.addFilter(QSensorFilter filter)'''
    def error(self):
        '''int QSensor.error()'''
        return int()
    def description(self):
        '''str QSensor.description()'''
        return str()
    def setOutputRange(self, index):
        '''void QSensor.setOutputRange(int index)'''
    def outputRange(self):
        '''int QSensor.outputRange()'''
        return int()
    def outputRanges(self):
        '''list-of-qoutputrange QSensor.outputRanges()'''
        return [qoutputrange()]
    def setDataRate(self, rate):
        '''void QSensor.setDataRate(int rate)'''
    def dataRate(self):
        '''int QSensor.dataRate()'''
        return int()
    def availableDataRates(self):
        '''list-of-tuple-of-int-int QSensor.availableDataRates()'''
        return [tuple-of-int-int()]
    def setSkipDuplicates(self, skipDuplicates):
        '''void QSensor.setSkipDuplicates(bool skipDuplicates)'''
    def skipDuplicates(self):
        '''bool QSensor.skipDuplicates()'''
        return bool()
    def setAlwaysOn(self, alwaysOn):
        '''void QSensor.setAlwaysOn(bool alwaysOn)'''
    def isAlwaysOn(self):
        '''bool QSensor.isAlwaysOn()'''
        return bool()
    def isActive(self):
        '''bool QSensor.isActive()'''
        return bool()
    def setActive(self, active):
        '''void QSensor.setActive(bool active)'''
    def isBusy(self):
        '''bool QSensor.isBusy()'''
        return bool()
    def isConnectedToBackend(self):
        '''bool QSensor.isConnectedToBackend()'''
        return bool()
    def connectToBackend(self):
        '''bool QSensor.connectToBackend()'''
        return bool()
    def type(self):
        '''QByteArray QSensor.type()'''
        return QByteArray()
    def setIdentifier(self, identifier):
        '''void QSensor.setIdentifier(QByteArray identifier)'''
    def identifier(self):
        '''QByteArray QSensor.identifier()'''
        return QByteArray()


class QAccelerometer(QSensor):
    """"""
    # Enum QAccelerometer.AccelerationMode
    Combined = 0
    Gravity = 0
    User = 0

    def __init__(self, parent = None):
        '''void QAccelerometer.__init__(QObject parent = None)'''
    accelerationModeChanged = pyqtSignal() # void accelerationModeChanged(QAccelerometer::AccelerationMode) - signal
    def reading(self):
        '''QAccelerometerReading QAccelerometer.reading()'''
        return QAccelerometerReading()
    def setAccelerationMode(self, accelerationMode):
        '''void QAccelerometer.setAccelerationMode(QAccelerometer.AccelerationMode accelerationMode)'''
    def accelerationMode(self):
        '''QAccelerometer.AccelerationMode QAccelerometer.accelerationMode()'''
        return QAccelerometer.AccelerationMode()


class QAltimeterReading(QSensorReading):
    """"""
    def setAltitude(self, altitude):
        '''void QAltimeterReading.setAltitude(float altitude)'''
    def altitude(self):
        '''float QAltimeterReading.altitude()'''
        return float()


class QAltimeterFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QAltimeterFilter.__init__()'''
    def __init__(self):
        '''QAltimeterFilter QAltimeterFilter.__init__()'''
        return QAltimeterFilter()
    def filter(self, reading):
        '''abstract bool QAltimeterFilter.filter(QAltimeterReading reading)'''
        return bool()


class QAltimeter(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QAltimeter.__init__(QObject parent = None)'''
    def reading(self):
        '''QAltimeterReading QAltimeter.reading()'''
        return QAltimeterReading()


class QAmbientLightReading(QSensorReading):
    """"""
    # Enum QAmbientLightReading.LightLevel
    Undefined = 0
    Dark = 0
    Twilight = 0
    Light = 0
    Bright = 0
    Sunny = 0

    def setLightLevel(self, lightLevel):
        '''void QAmbientLightReading.setLightLevel(QAmbientLightReading.LightLevel lightLevel)'''
    def lightLevel(self):
        '''QAmbientLightReading.LightLevel QAmbientLightReading.lightLevel()'''
        return QAmbientLightReading.LightLevel()


class QAmbientLightFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QAmbientLightFilter.__init__()'''
    def __init__(self):
        '''QAmbientLightFilter QAmbientLightFilter.__init__()'''
        return QAmbientLightFilter()
    def filter(self, reading):
        '''abstract bool QAmbientLightFilter.filter(QAmbientLightReading reading)'''
        return bool()


class QAmbientLightSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QAmbientLightSensor.__init__(QObject parent = None)'''
    def reading(self):
        '''QAmbientLightReading QAmbientLightSensor.reading()'''
        return QAmbientLightReading()


class QAmbientTemperatureReading(QSensorReading):
    """"""
    def setTemperature(self, temperature):
        '''void QAmbientTemperatureReading.setTemperature(float temperature)'''
    def temperature(self):
        '''float QAmbientTemperatureReading.temperature()'''
        return float()


class QAmbientTemperatureFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QAmbientTemperatureFilter.__init__()'''
    def __init__(self):
        '''QAmbientTemperatureFilter QAmbientTemperatureFilter.__init__()'''
        return QAmbientTemperatureFilter()
    def filter(self, reading):
        '''abstract bool QAmbientTemperatureFilter.filter(QAmbientTemperatureReading reading)'''
        return bool()


class QAmbientTemperatureSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QAmbientTemperatureSensor.__init__(QObject parent = None)'''
    def reading(self):
        '''QAmbientTemperatureReading QAmbientTemperatureSensor.reading()'''
        return QAmbientTemperatureReading()


class QCompassReading(QSensorReading):
    """"""
    def setCalibrationLevel(self, calibrationLevel):
        '''void QCompassReading.setCalibrationLevel(float calibrationLevel)'''
    def calibrationLevel(self):
        '''float QCompassReading.calibrationLevel()'''
        return float()
    def setAzimuth(self, azimuth):
        '''void QCompassReading.setAzimuth(float azimuth)'''
    def azimuth(self):
        '''float QCompassReading.azimuth()'''
        return float()


class QCompassFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QCompassFilter.__init__()'''
    def __init__(self):
        '''QCompassFilter QCompassFilter.__init__()'''
        return QCompassFilter()
    def filter(self, reading):
        '''abstract bool QCompassFilter.filter(QCompassReading reading)'''
        return bool()


class QCompass(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QCompass.__init__(QObject parent = None)'''
    def reading(self):
        '''QCompassReading QCompass.reading()'''
        return QCompassReading()


class QDistanceReading(QSensorReading):
    """"""
    def setDistance(self, distance):
        '''void QDistanceReading.setDistance(float distance)'''
    def distance(self):
        '''float QDistanceReading.distance()'''
        return float()


class QDistanceFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QDistanceFilter.__init__()'''
    def __init__(self):
        '''QDistanceFilter QDistanceFilter.__init__()'''
        return QDistanceFilter()
    def filter(self, reading):
        '''abstract bool QDistanceFilter.filter(QDistanceReading reading)'''
        return bool()


class QDistanceSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QDistanceSensor.__init__(QObject parent = None)'''
    def reading(self):
        '''QDistanceReading QDistanceSensor.reading()'''
        return QDistanceReading()


class QGyroscopeReading(QSensorReading):
    """"""
    def setZ(self, z):
        '''void QGyroscopeReading.setZ(float z)'''
    def z(self):
        '''float QGyroscopeReading.z()'''
        return float()
    def setY(self, y):
        '''void QGyroscopeReading.setY(float y)'''
    def y(self):
        '''float QGyroscopeReading.y()'''
        return float()
    def setX(self, x):
        '''void QGyroscopeReading.setX(float x)'''
    def x(self):
        '''float QGyroscopeReading.x()'''
        return float()


class QGyroscopeFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QGyroscopeFilter.__init__()'''
    def __init__(self):
        '''QGyroscopeFilter QGyroscopeFilter.__init__()'''
        return QGyroscopeFilter()
    def filter(self, reading):
        '''abstract bool QGyroscopeFilter.filter(QGyroscopeReading reading)'''
        return bool()


class QGyroscope(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QGyroscope.__init__(QObject parent = None)'''
    def reading(self):
        '''QGyroscopeReading QGyroscope.reading()'''
        return QGyroscopeReading()


class QHolsterReading(QSensorReading):
    """"""
    def setHolstered(self, holstered):
        '''void QHolsterReading.setHolstered(bool holstered)'''
    def holstered(self):
        '''bool QHolsterReading.holstered()'''
        return bool()


class QHolsterFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QHolsterFilter.__init__()'''
    def __init__(self):
        '''QHolsterFilter QHolsterFilter.__init__()'''
        return QHolsterFilter()
    def filter(self, reading):
        '''abstract bool QHolsterFilter.filter(QHolsterReading reading)'''
        return bool()


class QHolsterSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QHolsterSensor.__init__(QObject parent = None)'''
    def reading(self):
        '''QHolsterReading QHolsterSensor.reading()'''
        return QHolsterReading()


class QIRProximityReading(QSensorReading):
    """"""
    def setReflectance(self, reflectance):
        '''void QIRProximityReading.setReflectance(float reflectance)'''
    def reflectance(self):
        '''float QIRProximityReading.reflectance()'''
        return float()


class QIRProximityFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QIRProximityFilter.__init__()'''
    def __init__(self):
        '''QIRProximityFilter QIRProximityFilter.__init__()'''
        return QIRProximityFilter()
    def filter(self, reading):
        '''abstract bool QIRProximityFilter.filter(QIRProximityReading reading)'''
        return bool()


class QIRProximitySensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QIRProximitySensor.__init__(QObject parent = None)'''
    def reading(self):
        '''QIRProximityReading QIRProximitySensor.reading()'''
        return QIRProximityReading()


class QLightReading(QSensorReading):
    """"""
    def setLux(self, lux):
        '''void QLightReading.setLux(float lux)'''
    def lux(self):
        '''float QLightReading.lux()'''
        return float()


class QLightFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QLightFilter.__init__()'''
    def __init__(self):
        '''QLightFilter QLightFilter.__init__()'''
        return QLightFilter()
    def filter(self, reading):
        '''abstract bool QLightFilter.filter(QLightReading reading)'''
        return bool()


class QLightSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QLightSensor.__init__(QObject parent = None)'''
    fieldOfViewChanged = pyqtSignal() # void fieldOfViewChanged(qreal) - signal
    def setFieldOfView(self, fieldOfView):
        '''void QLightSensor.setFieldOfView(float fieldOfView)'''
    def fieldOfView(self):
        '''float QLightSensor.fieldOfView()'''
        return float()
    def reading(self):
        '''QLightReading QLightSensor.reading()'''
        return QLightReading()


class QMagnetometerReading(QSensorReading):
    """"""
    def setCalibrationLevel(self, calibrationLevel):
        '''void QMagnetometerReading.setCalibrationLevel(float calibrationLevel)'''
    def calibrationLevel(self):
        '''float QMagnetometerReading.calibrationLevel()'''
        return float()
    def setZ(self, z):
        '''void QMagnetometerReading.setZ(float z)'''
    def z(self):
        '''float QMagnetometerReading.z()'''
        return float()
    def setY(self, y):
        '''void QMagnetometerReading.setY(float y)'''
    def y(self):
        '''float QMagnetometerReading.y()'''
        return float()
    def setX(self, x):
        '''void QMagnetometerReading.setX(float x)'''
    def x(self):
        '''float QMagnetometerReading.x()'''
        return float()


class QMagnetometerFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QMagnetometerFilter.__init__()'''
    def __init__(self):
        '''QMagnetometerFilter QMagnetometerFilter.__init__()'''
        return QMagnetometerFilter()
    def filter(self, reading):
        '''abstract bool QMagnetometerFilter.filter(QMagnetometerReading reading)'''
        return bool()


class QMagnetometer(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QMagnetometer.__init__(QObject parent = None)'''
    returnGeoValuesChanged = pyqtSignal() # void returnGeoValuesChanged(bool) - signal
    def setReturnGeoValues(self, returnGeoValues):
        '''void QMagnetometer.setReturnGeoValues(bool returnGeoValues)'''
    def returnGeoValues(self):
        '''bool QMagnetometer.returnGeoValues()'''
        return bool()
    def reading(self):
        '''QMagnetometerReading QMagnetometer.reading()'''
        return QMagnetometerReading()


class QOrientationReading(QSensorReading):
    """"""
    # Enum QOrientationReading.Orientation
    Undefined = 0
    TopUp = 0
    TopDown = 0
    LeftUp = 0
    RightUp = 0
    FaceUp = 0
    FaceDown = 0

    def setOrientation(self, orientation):
        '''void QOrientationReading.setOrientation(QOrientationReading.Orientation orientation)'''
    def orientation(self):
        '''QOrientationReading.Orientation QOrientationReading.orientation()'''
        return QOrientationReading.Orientation()


class QOrientationFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QOrientationFilter.__init__()'''
    def __init__(self):
        '''QOrientationFilter QOrientationFilter.__init__()'''
        return QOrientationFilter()
    def filter(self, reading):
        '''abstract bool QOrientationFilter.filter(QOrientationReading reading)'''
        return bool()


class QOrientationSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QOrientationSensor.__init__(QObject parent = None)'''
    def reading(self):
        '''QOrientationReading QOrientationSensor.reading()'''
        return QOrientationReading()


class QPressureReading(QSensorReading):
    """"""
    def setTemperature(self, temperature):
        '''void QPressureReading.setTemperature(float temperature)'''
    def temperature(self):
        '''float QPressureReading.temperature()'''
        return float()
    def setPressure(self, pressure):
        '''void QPressureReading.setPressure(float pressure)'''
    def pressure(self):
        '''float QPressureReading.pressure()'''
        return float()


class QPressureFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QPressureFilter.__init__()'''
    def __init__(self):
        '''QPressureFilter QPressureFilter.__init__()'''
        return QPressureFilter()
    def filter(self, reading):
        '''abstract bool QPressureFilter.filter(QPressureReading reading)'''
        return bool()


class QPressureSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QPressureSensor.__init__(QObject parent = None)'''
    def reading(self):
        '''QPressureReading QPressureSensor.reading()'''
        return QPressureReading()


class QProximityReading(QSensorReading):
    """"""
    def setClose(self, close):
        '''void QProximityReading.setClose(bool close)'''
    def close(self):
        '''bool QProximityReading.close()'''
        return bool()


class QProximityFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QProximityFilter.__init__()'''
    def __init__(self):
        '''QProximityFilter QProximityFilter.__init__()'''
        return QProximityFilter()
    def filter(self, reading):
        '''abstract bool QProximityFilter.filter(QProximityReading reading)'''
        return bool()


class QProximitySensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QProximitySensor.__init__(QObject parent = None)'''
    def reading(self):
        '''QProximityReading QProximitySensor.reading()'''
        return QProximityReading()


class qoutputrange():
    """"""
    accuracy = None # float - member
    maximum = None # float - member
    minimum = None # float - member
    def __init__(self):
        '''void qoutputrange.__init__()'''
    def __init__(self):
        '''qoutputrange qoutputrange.__init__()'''
        return qoutputrange()


class QTapReading(QSensorReading):
    """"""
    # Enum QTapReading.TapDirection
    Undefined = 0
    X = 0
    Y = 0
    Z = 0
    X_Pos = 0
    Y_Pos = 0
    Z_Pos = 0
    X_Neg = 0
    Y_Neg = 0
    Z_Neg = 0
    X_Both = 0
    Y_Both = 0
    Z_Both = 0

    def setDoubleTap(self, doubleTap):
        '''void QTapReading.setDoubleTap(bool doubleTap)'''
    def isDoubleTap(self):
        '''bool QTapReading.isDoubleTap()'''
        return bool()
    def setTapDirection(self, tapDirection):
        '''void QTapReading.setTapDirection(QTapReading.TapDirection tapDirection)'''
    def tapDirection(self):
        '''QTapReading.TapDirection QTapReading.tapDirection()'''
        return QTapReading.TapDirection()


class QTapFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QTapFilter.__init__()'''
    def __init__(self):
        '''QTapFilter QTapFilter.__init__()'''
        return QTapFilter()
    def filter(self, reading):
        '''abstract bool QTapFilter.filter(QTapReading reading)'''
        return bool()


class QTapSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QTapSensor.__init__(QObject parent = None)'''
    returnDoubleTapEventsChanged = pyqtSignal() # void returnDoubleTapEventsChanged(bool) - signal
    def setReturnDoubleTapEvents(self, returnDoubleTapEvents):
        '''void QTapSensor.setReturnDoubleTapEvents(bool returnDoubleTapEvents)'''
    def returnDoubleTapEvents(self):
        '''bool QTapSensor.returnDoubleTapEvents()'''
        return bool()
    def reading(self):
        '''QTapReading QTapSensor.reading()'''
        return QTapReading()


class QTiltReading(QSensorReading):
    """"""
    def setXRotation(self, x):
        '''void QTiltReading.setXRotation(float x)'''
    def xRotation(self):
        '''float QTiltReading.xRotation()'''
        return float()
    def setYRotation(self, y):
        '''void QTiltReading.setYRotation(float y)'''
    def yRotation(self):
        '''float QTiltReading.yRotation()'''
        return float()


class QTiltFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QTiltFilter.__init__()'''
    def __init__(self):
        '''QTiltFilter QTiltFilter.__init__()'''
        return QTiltFilter()
    def filter(self, reading):
        '''abstract bool QTiltFilter.filter(QTiltReading reading)'''
        return bool()


class QTiltSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QTiltSensor.__init__(QObject parent = None)'''
    def calibrate(self):
        '''void QTiltSensor.calibrate()'''
    def reading(self):
        '''QTiltReading QTiltSensor.reading()'''
        return QTiltReading()


class QRotationReading(QSensorReading):
    """"""
    def setFromEuler(self, x, y, z):
        '''void QRotationReading.setFromEuler(float x, float y, float z)'''
    def z(self):
        '''float QRotationReading.z()'''
        return float()
    def y(self):
        '''float QRotationReading.y()'''
        return float()
    def x(self):
        '''float QRotationReading.x()'''
        return float()


class QRotationFilter(QSensorFilter):
    """"""
    def __init__(self):
        '''void QRotationFilter.__init__()'''
    def __init__(self):
        '''QRotationFilter QRotationFilter.__init__()'''
        return QRotationFilter()
    def filter(self, reading):
        '''abstract bool QRotationFilter.filter(QRotationReading reading)'''
        return bool()


class QRotationSensor(QSensor):
    """"""
    def __init__(self, parent = None):
        '''void QRotationSensor.__init__(QObject parent = None)'''
    hasZChanged = pyqtSignal() # void hasZChanged(bool) - signal
    def setHasZ(self, hasZ):
        '''void QRotationSensor.setHasZ(bool hasZ)'''
    def hasZ(self):
        '''bool QRotationSensor.hasZ()'''
        return bool()
    def reading(self):
        '''QRotationReading QRotationSensor.reading()'''
        return QRotationReading()





#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Access system-specific parameters and functions.


This module provides access to some variables used or maintained by the
interpreter and to functions that interact strongly with the interpreter. It is
always available.


"""
"""
The list of command line arguments passed to a Python script. ``argv[0]`` is the
script name (it is operating system dependent whether this is a full pathname or
not).  If the command was executed using the :option:`-c` command line option to
the interpreter, ``argv[0]`` is set to the string ``'-c'``.  If no script name
was passed to the Python interpreter, ``argv[0]`` is the empty string.

To loop over the standard input, or the list of files given on the
command line, see the :mod:`fileinput` module.


"""
argv = [str()]
"""
An indicator of the native byte order.  This will have the value ``'big'`` on
big-endian (most-significant byte first) platforms, and ``'little'`` on
little-endian (least-significant byte first) platforms.

"""
byteorder = str()
"""
A triple (repo, branch, version) representing the Subversion information of the
Python interpreter. *repo* is the name of the repository, ``'CPython'``.
*branch* is a string of one of the forms ``'trunk'``, ``'branches/name'`` or
``'tags/name'``. *version* is the output of ``svnversion``, if the interpreter
was built from a Subversion checkout; it contains the revision number (range)
and possibly a trailing 'M' if there were local modifications. If the tree was
exported (or svnversion was not available), it is the revision of
``Include/patchlevel.h`` if the branch is a tag. Otherwise, it is ``None``.

"""
subversion = (str(), str(), str())
"""
A tuple of strings giving the names of all modules that are compiled into this
Python interpreter.  (This information is not available in any other way ---
``modules.keys()`` only lists the imported modules.)


"""
builtin_module_names = (str())
"""
A string containing the copyright pertaining to the Python interpreter.


"""
copyright = str()
"""
Integer specifying the handle of the Python DLL. Availability: Windows.


"""
dllhandle = int()
"""__excepthook__

These objects contain the original values of ``displayhook`` and ``excepthook``
at the start of the program.  They are saved so that ``displayhook`` and
``excepthook`` can be restored in case they happen to get replaced with broken
objects.


"""
__displayhook__ = None
exc_value = None
exc_traceback = None
exc_type = None
"""
A string giving the site-specific directory prefix where the platform-dependent
Python files are installed; by default, this is also ``'/usr/local'``.  This can
be set at build time with the ``--exec-prefix`` argument to the
:program:`configure` script.  Specifically, all configuration files (e.g. the
:file:`pyconfig.h` header file) are installed in the directory ``exec_prefix +
'/lib/pythonversion/config'``, and shared library modules are installed in
``exec_prefix + '/lib/pythonversion/lib-dynload'``, where *version* is equal to
``version[:3]``.


"""
exec_prefix = str()
"""
A string giving the name of the executable binary for the Python interpreter, on
systems where this makes sense.


"""
executable = str()
"""
This value is not actually defined by the module, but can be set by the user (or
by a program) to specify a clean-up action at program exit.  When set, it should
be a parameterless function.  This function will be called when the interpreter
exits.  Only one function may be installed in this way; to allow multiple
functions which will be called at termination, use the :mod:`atexit` module.

"""
exitfunc = lambda: None
"""
The struct sequence *flags* exposes the status of command line flags. The
attributes are read only.

============================= ===================================
attribute                     flag
============================= ===================================
:const:`debug`                :option:`-d`
:const:`py3k_warning`         :option:`-3`
:const:`division_warning`     :option:`-Q`
:const:`division_new`         :option:`-Qnew <-Q>`
:const:`inspect`              :option:`-i`
:const:`interactive`          :option:`-i`
:const:`optimize`             :option:`-O` or :option:`-OO`
:const:`dont_write_bytecode`  :option:`-B`
:const:`no_user_site`         :option:`-s`
:const:`no_site`              :option:`-S`
:const:`ignore_environment`   :option:`-E`
:const:`tabcheck`             :option:`-t` or :option:`-tt <-t>`
:const:`verbose`              :option:`-v`
:const:`unicode`              :option:`-U`
:const:`bytes_warning`        :option:`-b`
============================= ===================================

"""
flags = None
"""
A structseq holding information about the float type. It contains low level
information about the precision and internal representation.  The values
correspond to the various floating-point constants defined in the standard
header file :file:`float.h` for the 'C' programming language; see section
5.2.4.2.2 of the 1999 ISO/IEC C standard [C99]_, 'Characteristics of
floating types', for details.

+---------------------+----------------+--------------------------------------------------+
| attribute           | float.h macro  | explanation                                      |
+=====================+================+==================================================+
| :const:`epsilon`    | DBL_EPSILON    | difference between 1 and the least value greater |
|                     |                | than 1 that is representable as a float          |
+---------------------+----------------+--------------------------------------------------+
| :const:`dig`        | DBL_DIG        | maximum number of decimal digits that can be     |
|                     |                | faithfully represented in a float;  see below    |
+---------------------+----------------+--------------------------------------------------+
| :const:`mant_dig`   | DBL_MANT_DIG   | float precision: the number of base-``radix``    |
|                     |                | digits in the significand of a float             |
+---------------------+----------------+--------------------------------------------------+
| :const:`max`        | DBL_MAX        | maximum representable finite float               |
+---------------------+----------------+--------------------------------------------------+
| :const:`max_exp`    | DBL_MAX_EXP    | maximum integer e such that ``radix**(e-1)`` is  |
|                     |                | a representable finite float                     |
+---------------------+----------------+--------------------------------------------------+
| :const:`max_10_exp` | DBL_MAX_10_EXP | maximum integer e such that ``10**e`` is in the  |
|                     |                | range of representable finite floats             |
+---------------------+----------------+--------------------------------------------------+
| :const:`min`        | DBL_MIN        | minimum positive normalized float                |
+---------------------+----------------+--------------------------------------------------+
| :const:`min_exp`    | DBL_MIN_EXP    | minimum integer e such that ``radix**(e-1)`` is  |
|                     |                | a normalized float                               |
+---------------------+----------------+--------------------------------------------------+
| :const:`min_10_exp` | DBL_MIN_10_EXP | minimum integer e such that ``10**e`` is a       |
|                     |                | normalized float                                 |
+---------------------+----------------+--------------------------------------------------+
| :const:`radix`      | FLT_RADIX      | radix of exponent representation                 |
+---------------------+----------------+--------------------------------------------------+
| :const:`rounds`     | FLT_ROUNDS     | constant representing rounding mode              |
|                     |                | used for arithmetic operations                   |
+---------------------+----------------+--------------------------------------------------+

The attribute :attr:`sys.float_info.dig` needs further explanation.  If
``s`` is any string representing a decimal number with at most
:attr:`sys.float_info.dig` significant digits, then converting ``s`` to a
float and back again will recover a string representing the same decimal
value::

>>> import sys
>>> sys.float_info.dig
15
>>> s = '3.14159265358979'    # decimal string with 15 significant digits
>>> format(float(s), '.15g')  # convert to float and back -> same value
'3.14159265358979'

But for strings with more than :attr:`sys.float_info.dig` significant digits,
this isn't always true::

>>> s = '9876543211234567'    # 16 significant digits is too many!
>>> format(float(s), '.16g')  # conversion changes value
'9876543211234568'

"""
float_info = None
"""
A string indicating how the :func:`repr` function behaves for
floats.  If the string has value ``'short'`` then for a finite
float ``x``, ``repr(x)`` aims to produce a short string with the
property that ``float(repr(x)) == x``.  This is the usual behaviour
in Python 2.7 and later.  Otherwise, ``float_repr_style`` has value
``'legacy'`` and ``repr(x)`` behaves in the same way as it did in
versions of Python prior to 2.7.

"""
float_repr_style = str()
"""
The version number encoded as a single integer.  This is guaranteed to increase
with each version, including proper support for non-production releases.  For
example, to test that the Python interpreter is at least version 1.5.2, use::

if sys.hexversion >= 0x010502F0:
# use some advanced feature
more
else:
# use an alternative implementation or warn the user
more

This is called ``hexversion`` since it only really looks meaningful when viewed
as the result of passing it to the built-in :func:`hex` function.  The
``version_info`` value may be used for a more human-friendly encoding of the
same information.

The ``hexversion`` is a 32-bit number with the following layout:

+-------------------------+------------------------------------------------+
| Bits (big endian order) | Meaning                                        |
+=========================+================================================+
| :const:`1-8`            |  ``PY_MAJOR_VERSION``  (the ``2`` in           |
|                         |  ``2.1.0a3``)                                  |
+-------------------------+------------------------------------------------+
| :const:`9-16`           |  ``PY_MINOR_VERSION``  (the ``1`` in           |
|                         |  ``2.1.0a3``)                                  |
+-------------------------+------------------------------------------------+
| :const:`17-24`          |  ``PY_MICRO_VERSION``  (the ``0`` in           |
|                         |  ``2.1.0a3``)                                  |
+-------------------------+------------------------------------------------+
| :const:`25-28`          |  ``PY_RELEASE_LEVEL``  (``0xA`` for alpha,     |
|                         |  ``0xB`` for beta, ``0xC`` for release         |
|                         |  candidate and ``0xF`` for final)              |
+-------------------------+------------------------------------------------+
| :const:`29-32`          |  ``PY_RELEASE_SERIAL``  (the ``3`` in          |
|                         |  ``2.1.0a3``, zero for final releases)         |
+-------------------------+------------------------------------------------+

Thus ``2.1.0a3`` is hexversion ``0x020100a3``.

"""
hexversion = str()
"""
A struct sequence that holds information about Python's
internal representation of integers.  The attributes are read only.

+-------------------------+----------------------------------------------+
| Attribute               | Explanation                                  |
+=========================+==============================================+
| :const:`bits_per_digit` | number of bits held in each digit.  Python   |
|                         | integers are stored internally in base       |
|                         | ``2**long_info.bits_per_digit``              |
+-------------------------+----------------------------------------------+
| :const:`sizeof_digit`   | size in bytes of the C type used to          |
|                         | represent a digit                            |
+-------------------------+----------------------------------------------+

"""
long_info = None
"""
These three variables are not always defined; they are set when an exception is
not handled and the interpreter prints an error message and a stack traceback.
Their intended use is to allow an interactive user to import a debugger module
and engage in post-mortem debugging without having to re-execute the command
that caused the error.  (Typical use is ``import pdb; pdb.pm()`` to enter the
post-mortem debugger; see chapter :ref:`debugger` for
more information.)

The meaning of the variables is the same as that of the return values from
:func:`exc_info` above.  (Since there is only one interactive thread,
thread-safety is not a concern for these variables, unlike for ``exc_type``
etc.)


"""
last_traceback = None
last_value = None
last_type = None
"""
The largest positive integer supported by Python's regular integer type.  This
is at least 2\*\*31-1.  The largest negative integer is ``-maxint-1`` --- the
asymmetry results from the use of 2's complement binary arithmetic.

"""
maxint = int()
"""
The largest positive integer supported by the platform's Py_ssize_t type,
and thus the maximum size lists, strings, dicts, and many other containers
can have.

"""
maxsize = int()
"""
An integer giving the largest supported code point for a Unicode character.  The
value of this depends on the configuration option that specifies whether Unicode
characters are stored as UCS-2 or UCS-4.


"""
maxunicode = int()
"""
A list of :term:`finder` objects that have their :meth:`find_module`
methods called to see if one of the objects can find the module to be
imported. The :meth:`find_module` method is called at least with the
absolute name of the module being imported. If the module to be imported is
contained in package then the parent package's :attr:`__path__` attribute
is passed in as a second argument. The method returns :keyword:`None` if
the module cannot be found, else returns a :term:`loader`.

:data:`sys.meta_path` is searched before any implicit default finders or
:data:`sys.path`.

See :pep:`302` for the original specification.


"""
meta_path = [None]
modules = None
path = [str()]
"""
A list of callables that take a path argument to try to create a
:term:`finder` for the path. If a finder can be created, it is to be
returned by the callable, else raise :exc:`ImportError`.

Originally specified in :pep:`302`.


"""
path_hooks = [lambda: None]
"""
A dictionary acting as a cache for :term:`finder` objects. The keys are
paths that have been passed to :data:`sys.path_hooks` and the values are
the finders that are found. If a path is a valid file system path but no
explicit finder is found on :data:`sys.path_hooks` then :keyword:`None` is
stored to represent the implicit default finder should be used. If the path
is not an existing path then :class:`imp.NullImporter` is set.

Originally specified in :pep:`302`.


"""
path_importer_cache = None
"""
This string contains a platform identifier that can be used to append
platform-specific components to :data:`sys.path`, for instance.

For Unix systems, this is the lowercased OS name as returned by ``uname -s``
with the first part of the version as returned by ``uname -r`` appended,
e.g. ``'sunos5'`` or ``'linux2'``, *at the time when Python was built*.
For other systems, the values are:

================ ===========================
System           :data:`platform` value
================ ===========================
Windows          ``'win32'``
Windows/Cygwin   ``'cygwin'``
Mac OS X         ``'darwin'``
OS/2             ``'os2'``
OS/2 EMX         ``'os2emx'``
RiscOS           ``'riscos'``
AtheOS           ``'atheos'``
================ ===========================


"""
platform = str()
"""
A string giving the site-specific directory prefix where the platform
independent Python files are installed; by default, this is the string
``'/usr/local'``.  This can be set at build time with the ``--prefix``
argument to the :program:`configure` script.  The main collection of Python
library modules is installed in the directory ``prefix + '/lib/pythonversion'``
while the platform independent header files (all except :file:`pyconfig.h`) are
stored in ``prefix + '/include/pythonversion'``, where *version* is equal to
``version[:3]``.


"""
prefix = str()
ps2 = None
ps1 = None
"""
Bool containing the status of the Python 3.0 warning flag. It's ``True``
when Python is started with the -3 option.  (This should be considered
read-only; setting it to a different value doesn't have an effect on
Python 3.0 warnings.)

"""
py3kwarning = False
"""
If this is true, Python won't try to write ``.pyc`` or ``.pyo`` files on the
import of source modules.  This value is initially set to ``True`` or ``False``
depending on the ``-B`` command line option and the ``PYTHONDONTWRITEBYTECODE``
environment variable, but you can set it yourself to control bytecode file
generation.

"""
dont_write_bytecode = False
"""
File objects corresponding to the interpreter's standard input, output and error
streams.  ``stdin`` is used for all interpreter input except for scripts but
including calls to :func:`input` and :func:`raw_input`.  ``stdout`` is used for
the output of :keyword:`print` and :term:`expression` statements and for the
prompts of :func:`input` and :func:`raw_input`. The interpreter's own prompts
and (almost all of) its error messages go to ``stderr``.  ``stdout`` and
``stderr`` needn't be built-in file objects: any object is acceptable as long
as it has a :meth:`write` method that takes a string argument.  (Changing these
objects doesn't affect the standard I/O streams of processes executed by
:func:`os.popen`, :func:`os.system` or the :func:`exec\*` family of functions in
the :mod:`os` module.)


"""
stdin = open("stdin", "rw")
"""
File objects corresponding to the interpreter's standard input, output and error
streams.  ``stdin`` is used for all interpreter input except for scripts but
including calls to :func:`input` and :func:`raw_input`.  ``stdout`` is used for
the output of :keyword:`print` and :term:`expression` statements and for the
prompts of :func:`input` and :func:`raw_input`. The interpreter's own prompts
and (almost all of) its error messages go to ``stderr``.  ``stdout`` and
``stderr`` needn't be built-in file objects: any object is acceptable as long
as it has a :meth:`write` method that takes a string argument.  (Changing these
objects doesn't affect the standard I/O streams of processes executed by
:func:`os.popen`, :func:`os.system` or the :func:`exec\*` family of functions in
the :mod:`os` module.)


"""
stdout = open("stdout", "rw")
"""
File objects corresponding to the interpreter's standard input, output and error
streams.  ``stdin`` is used for all interpreter input except for scripts but
including calls to :func:`input` and :func:`raw_input`.  ``stdout`` is used for
the output of :keyword:`print` and :term:`expression` statements and for the
prompts of :func:`input` and :func:`raw_input`. The interpreter's own prompts
and (almost all of) its error messages go to ``stderr``.  ``stdout`` and
``stderr`` needn't be built-in file objects: any object is acceptable as long
as it has a :meth:`write` method that takes a string argument.  (Changing these
objects doesn't affect the standard I/O streams of processes executed by
:func:`os.popen`, :func:`os.system` or the :func:`exec\*` family of functions in
the :mod:`os` module.)


"""
stderr = open("stderr", "rw")
"""
These objects contain the original values of ``stdin``, ``stderr`` and
``stdout`` at the start of the program.  They are used during finalization,
and could be useful to print to the actual standard stream no matter if the
``sys.std*`` object has been redirected.

It can also be used to restore the actual files to known working file objects
in case they have been overwritten with a broken object.  However, the
preferred way to do this is to explicitly save the previous stream before
replacing it, and restore the saved object.


"""
__stdout__ = stdout
__stderr__ = stderr
__stdin__ = stdin
"""
When this variable is set to an integer value, it determines the maximum number
of levels of traceback information printed when an unhandled exception occurs.
The default is ``1000``.  When set to ``0`` or less, all traceback information
is suppressed and only the exception type and value are printed.


"""
tracebacklimit = 1000
"""
A string containing the version number of the Python interpreter plus additional
information on the build number and compiler used.  This string is displayed
when the interactive interpreter is started.  Do not extract version information
out of it, rather, use :data:`version_info` and the functions provided by the
:mod:`platform` module.


"""
version = str()
"""
The C API version for this interpreter.  Programmers may find this useful when
debugging version conflicts between Python and extension modules.

"""
api_version = str()
"""
A tuple containing the five components of the version number: *major*, *minor*,
*micro*, *releaselevel*, and *serial*.  All values except *releaselevel* are
integers; the release level is ``'alpha'``, ``'beta'``, ``'candidate'``, or
``'final'``.  The ``version_info`` value corresponding to the Python version 2.0
is ``(2, 0, 0, 'final', 0)``.  The components can also be accessed by name,
so ``sys.version_info[0]`` is equivalent to ``sys.version_info.major``
and so on.

"""
version_info = (3, 5, 0, 0, 0)
"""
This is an implementation detail of the warnings framework; do not modify this
value.  Refer to the :mod:`warnings` module for more information on the warnings
framework.


"""
warnoptions = None
"""
The version number used to form registry keys on Windows platforms. This is
stored as string resource 1000 in the Python DLL.  The value is normally the
first three characters of :const:`version`.  It is provided in the :mod:`sys`
module for informational purposes; modifying this value has no effect on the
registry keys used by Python. Availability: Windows.

"""
winver = str()
def call_tracing(func,args):
	"""
	Call ``func(*args)``, while tracing is enabled.  The tracing state is saved,
	and restored afterwards.  This is intended to be called from a debugger from
	a checkpoint, to recursively debug some other code.
	
	
	"""
	pass
	
def _clear_type_cache():
	"""
	Clear the internal type cache. The type cache is used to speed up attribute
	and method lookups. Use the function *only* to drop unnecessary references
	during reference leak debugging.
	
	This function should be used for internal and specialized purposes only.
	
	"""
	pass
	
def _current_frames():
	"""
	Return a dictionary mapping each thread's identifier to the topmost stack frame
	currently active in that thread at the time the function is called. Note that
	functions in the :mod:`traceback` module can build the call stack given such a
	frame.
	
	This is most useful for debugging deadlock:  this function does not require the
	deadlocked threads' cooperation, and such threads' call stacks are frozen for as
	long as they remain deadlocked.  The frame returned for a non-deadlocked thread
	may bear no relationship to that thread's current activity by the time calling
	code examines the frame.
	
	This function should be used for internal and specialized purposes only.
	
	"""
	dict()
	
def displayhook(value):
	"""
	If *value* is not ``None``, this function prints it to ``sys.stdout``, and saves
	it in ``__builtin__._``.
	
	``sys.displayhook`` is called on the result of evaluating an :term:`expression`
	entered in an interactive Python session.  The display of these values can be
	customized by assigning another one-argument function to ``sys.displayhook``.
	
	
	"""
	pass
	
def excepthook(type,value,traceback):
	"""
	This function prints out a given traceback and exception to ``sys.stderr``.
	
	When an exception is raised and uncaught, the interpreter calls
	``sys.excepthook`` with three arguments, the exception class, exception
	instance, and a traceback object.  In an interactive session this happens just
	before control is returned to the prompt; in a Python program this happens just
	before the program exits.  The handling of such top-level exceptions can be
	customized by assigning another three-argument function to ``sys.excepthook``.
	
	
	"""
	pass
	
def exc_info():
	"""
	This function returns a tuple of three values that give information about the
	exception that is currently being handled.  The information returned is specific
	both to the current thread and to the current stack frame.  If the current stack
	frame is not handling an exception, the information is taken from the calling
	stack frame, or its caller, and so on until a stack frame is found that is
	handling an exception.  Here, "handling an exception" is defined as "executing
	or having executed an except clause."  For any stack frame, only information
	about the most recently handled exception is accessible.
	
	"""
	return tuple()
	
def exc_clear():
	"""
	This function clears all information relating to the current or last exception
	that occurred in the current thread.  After calling this function,
	:func:`exc_info` will return three ``None`` values until another exception is
	raised in the current thread or the execution stack returns to a frame where
	another exception is being handled.
	
	This function is only needed in only a few obscure situations.  These include
	logging and error handling systems that report information on the last or
	current exception.  This function can also be used to try to free resources and
	trigger object finalization, though no guarantee is made as to what objects will
	be freed, if any.
	
	"""
	pass
	
def exit(arg: int):
	"""
	Exit from Python.  This is implemented by raising the :exc:`SystemExit`
	exception, so cleanup actions specified by finally clauses of :keyword:`try`
	statements are honored, and it is possible to intercept the exit attempt at
	an outer level.
	
	The optional argument *arg* can be an integer giving the exit status
	(defaulting to zero), or another type of object.  If it is an integer, zero
	is considered "successful termination" and any nonzero value is considered
	"abnormal termination" by shells and the like.  Most systems require it to be
	in the range 0-127, and produce undefined results otherwise.  Some systems
	have a convention for assigning specific meanings to specific exit codes, but
	these are generally underdeveloped; Unix programs generally use 2 for command
	line syntax errors and 1 for all other kind of errors.  If another type of
	object is passed, ``None`` is equivalent to passing zero, and any other
	object is printed to :data:`stderr` and results in an exit code of 1.  In
	particular, ``sys.exit("some error message")`` is a quick way to exit a
	program when an error occurs.
	
	Since :func:`exit` ultimately "only" raises an exception, it will only exit
	the process when called from the main thread, and the exception is not
	intercepted.
	
	
	"""
	pass
	
def getcheckinterval():
	"""
	Return the interpreter's "check interval"; see :func:`setcheckinterval`.
	
	"""
	return int()
	
def getdefaultencoding():
	"""
	Return the name of the current default string encoding used by the Unicode
	implementation.
	
	"""
	return str()
	
def getdlopenflags():
	"""
	Return the current value of the flags that are used for :cfunc:`dlopen` calls.
	The flag constants are defined in the :mod:`dl` and :mod:`DLFCN` modules.
	Availability: Unix.
	
	"""
	return str()
	
def getfilesystemencoding():
	"""
	Return the name of the encoding used to convert Unicode filenames into system
	file names, or ``None`` if the system default encoding is used. The result value
	depends on the operating system:
	
	* On Mac OS X, the encoding is ``'utf-8'``.
	
	* On Unix, the encoding is the user's preference according to the result of
	nl_langinfo(CODESET), or ``None`` if the ``nl_langinfo(CODESET)``
	failed.
	
	* On Windows NT+, file names are Unicode natively, so no conversion is
	performed. :func:`getfilesystemencoding` still returns ``'mbcs'``, as
	this is the encoding that applications should use when they explicitly
	want to convert Unicode strings to byte strings that are equivalent when
	used as file names.
	
	* On Windows 9x, the encoding is ``'mbcs'``.
	
	"""
	return "utf-8"
	
def getrefcount(object):
	"""
	Return the reference count of the *object*.  The count returned is generally one
	higher than you might expect, because it includes the (temporary) reference as
	an argument to :func:`getrefcount`.
	
	
	"""
	return 0
	
def getrecursionlimit():
	"""
	Return the current value of the recursion limit, the maximum depth of the Python
	interpreter stack.  This limit prevents infinite recursion from causing an
	overflow of the C stack and crashing Python.  It can be set by
	:func:`setrecursionlimit`.
	
	
	"""
	return 1000
	
def getsizeof(object,default):
	"""
	Return the size of an object in bytes. The object can be any type of
	object. All built-in objects will return correct results, but this
	does not have to hold true for third-party extensions as it is implementation
	specific.
	
	If given, *default* will be returned if the object does not provide means to
	retrieve the size.  Otherwise a :exc:`TypeError` will be raised.
	
	:func:`getsizeof` calls the object's ``__sizeof__`` method and adds an
	additional garbage collector overhead if the object is managed by the garbage
	collector.
	
	"""
	return 0
	
def _getframe(depth: int):
	"""
	Return a frame object from the call stack.  If optional integer *depth* is
	given, return the frame object that many calls below the top of the stack.  If
	that is deeper than the call stack, :exc:`ValueError` is raised.  The default
	for *depth* is zero, returning the frame at the top of the call stack.
	
	"""
	pass
	
def getprofile():
	pass
	
def gettrace():
	pass
	
def getwindowsversion():
	"""
	Return a named tuple describing the Windows version
	currently running.  The named elements are *major*, *minor*,
	*build*, *platform*, *service_pack*, *service_pack_minor*,
	*service_pack_major*, *suite_mask*, and *product_type*.
	*service_pack* contains a string while all other values are
	integers. The components can also be accessed by name, so
	``sys.getwindowsversion()[0]`` is equivalent to
	``sys.getwindowsversion().major``. For compatibility with prior
	versions, only the first 5 elements are retrievable by indexing.
	
	*platform* may be one of the following values:
	
	+-----------------------------------------+-------------------------+
	| Constant                                | Platform                |
	+=========================================+=========================+
	| :const:`0 (VER_PLATFORM_WIN32s)`        | Win32s on Windows 3.1   |
	+-----------------------------------------+-------------------------+
	| :const:`1 (VER_PLATFORM_WIN32_WINDOWS)` | Windows 95/98/ME        |
	+-----------------------------------------+-------------------------+
	| :const:`2 (VER_PLATFORM_WIN32_NT)`      | Windows NT/2000/XP/x64  |
	+-----------------------------------------+-------------------------+
	| :const:`3 (VER_PLATFORM_WIN32_CE)`      | Windows CE              |
	+-----------------------------------------+-------------------------+
	
	*product_type* may be one of the following values:
	
	+---------------------------------------+---------------------------------+
	| Constant                              | Meaning                         |
	+=======================================+=================================+
	| :const:`1 (VER_NT_WORKSTATION)`       | The system is a workstation.    |
	+---------------------------------------+---------------------------------+
	| :const:`2 (VER_NT_DOMAIN_CONTROLLER)` | The system is a domain          |
	|                                       | controller.                     |
	+---------------------------------------+---------------------------------+
	| :const:`3 (VER_NT_SERVER)`            | The system is a server, but not |
	|                                       | a domain controller.            |
	+---------------------------------------+---------------------------------+
	
	
	This function wraps the Win32 :cfunc:`GetVersionEx` function; see the
	Microsoft documentation on :cfunc:`OSVERSIONINFOEX` for more information
	about these fields.
	
	Availability: Windows.
	
	"""
	return (0, 0)
	
def setcheckinterval(interval: int):
	"""
	Set the interpreter's "check interval".  This integer value determines how often
	the interpreter checks for periodic things such as thread switches and signal
	handlers.  The default is ``100``, meaning the check is performed every 100
	Python virtual instructions. Setting it to a larger value may increase
	performance for programs using threads.  Setting it to a value ``<=`` 0 checks
	every virtual instruction, maximizing responsiveness as well as overhead.
	
	
	"""
	pass
	
def setdefaultencoding(name):
	"""
	Set the current default string encoding used by the Unicode implementation.  If
	*name* does not match any available encoding, :exc:`LookupError` is raised.
	This function is only intended to be used by the :mod:`site` module
	implementation and, where needed, by :mod:`sitecustomize`.  Once used by the
	:mod:`site` module, it is removed from the :mod:`sys` module's namespace.
	
	.. mod:`site` is not imported if the :option:`-S` option is passed
	to the interpreter, in which case this function will remain available.
	
	"""
	pass
	
def setdlopenflags(n):
	"""
	Set the flags used by the interpreter for :cfunc:`dlopen` calls, such as when
	the interpreter loads extension modules.  Among other things, this will enable a
	lazy resolving of symbols when importing a module, if called as
	``sys.setdlopenflags(0)``.  To share symbols across extension modules, call as
	``sys.setdlopenflags(dl.RTLD_NOW | dl.RTLD_GLOBAL)``.  Symbolic names for the
	flag modules can be either found in the :mod:`dl` module, or in the :mod:`DLFCN`
	module. If :mod:`DLFCN` is not available, it can be generated from
	:file:`/usr/include/dlfcn.h` using the :program:`h2py` script. Availability:
	Unix.
	
	"""
	pass
	
def setprofile(profilefunc):
	pass
	
def setrecursionlimit(limit):
	"""
	Set the maximum depth of the Python interpreter stack to *limit*.  This limit
	prevents infinite recursion from causing an overflow of the C stack and crashing
	Python.
	
	The highest possible limit is platform-dependent.  A user may need to set the
	limit higher when she has a program that requires deep recursion and a platform
	that supports a higher limit.  This should be done with care, because a too-high
	limit can lead to a crash.
	
	
	"""
	pass
	
def settrace(tracefunc):
	"""
	"""
	pass
	
def settscdump(on_flag):
	"""
	Activate dumping of VM measurements using the Pentium timestamp counter, if
	*on_flag* is true. Deactivate these dumps if *on_flag* is off. The function is
	available only if Python was compiled with ``--with-tsc``. To understand
	the output of this dump, read :file:`Python/ceval.c` in the Python sources.
	
	"""
	pass
	



#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Create multiple threads of control within one interpreter.

"""
"""
This is the type of lock objects.


"""
LockType = None
def start_new_thread(function,args,kwargs):
	"""
	Start a new thread and return its identifier.  The thread executes the function
	*function* with the argument list *args* (which must be a tuple).  The optional
	*kwargs* argument specifies a dictionary of keyword arguments. When the function
	returns, the thread silently exits.  When the function terminates with an
	unhandled exception, a stack trace is printed and then the thread exits (but
	other threads continue to run).
	
	
	"""
	pass
	
def interrupt_main():
	"""
	Raise a :exc:`KeyboardInterrupt` exception in the main thread.  A subthread can
	use this function to interrupt the main thread.
	
	"""
	pass
	
def exit():
	"""
	Raise the :exc:`SystemExit` exception.  When not caught, this will cause the
	thread to exit silently.
	
	..
	function:: exit_prog(status)
	
	Exit all threads and report the value of the integer argument
	*status* as the exit status of the entire program.
	**Caveat:** code in pending :keyword:`finally` clauses, in this thread
	or in other threads, is not executed.
	
	
	"""
	pass
	
def allocate_lock():
	"""
	Return a new lock object.  Methods of locks are described below.  The lock is
	initially unlocked.
	
	
	"""
	pass
	
def get_ident():
	"""
	Return the 'thread identifier' of the current thread.  This is a nonzero
	integer.  Its value has no direct meaning; it is intended as a magic cookie to
	be used e.g. to index a dictionary of thread-specific data.  Thread identifiers
	may be recycled when a thread exits and another thread is created.
	
	
	"""
	pass
	
def stack_size(size):
	"""
	Return the thread stack size used when creating new threads.  The optional
	*size* argument specifies the stack size to be used for subsequently created
	threads, and must be 0 (use platform or configured default) or a positive
	integer value of at least 32,768 (32kB). If changing the thread stack size is
	unsupported, the :exc:`error` exception is raised.  If the specified stack size is
	invalid, a :exc:`ValueError` is raised and the stack size is unmodified.  32kB
	is currently the minimum supported stack size value to guarantee sufficient
	stack space for the interpreter itself.  Note that some platforms may have
	particular restrictions on values for the stack size, such as requiring a
	minimum stack size > 32kB or requiring allocation in multiples of the system
	memory page size - platform documentation should be referred to for more
	information (4kB pages are common; using multiples of 4096 for the stack size is
	the suggested approach in the absence of more specific information).
	Availability: Windows, systems with POSIX threads.
	
	"""
	pass
	
